@@ -102,7 +102,15 @@ LogicalType ParquetReader::DeriveLogicalType(const SchemaElement &s_ele, bool bi
 				return LogicalType::UUID;
 			}
 		} else if (s_ele.logicalType.__isset.TIMESTAMP) {
+			if (s_ele.logicalType.TIMESTAMP.isAdjustedToUTC) {
+				return LogicalType::TIMESTAMP_TZ;
+			}
 			return LogicalType::TIMESTAMP;
+		} else if (s_ele.logicalType.__isset.TIME) {
+			if (s_ele.logicalType.TIME.isAdjustedToUTC) {
+				return LogicalType::TIME_TZ;
+			}
+			return LogicalType::TIME;
 		}
 	}
 	if (s_ele.__isset.converted_type) {
@@ -201,7 +209,7 @@ LogicalType ParquetReader::DeriveLogicalType(const SchemaElement &s_ele, bool bi
 		case ConvertedType::INTERVAL:
 			return LogicalType::INTERVAL;
 		case ConvertedType::JSON:
-			return LogicalType::JSON;
+			return LogicalType::VARCHAR;
 		case ConvertedType::MAP:
 		case ConvertedType::MAP_KEY_VALUE:
 		case ConvertedType::LIST:
@@ -249,13 +257,15 @@ unique_ptr<ColumnReader> ParquetReader::CreateReaderRecursive(const FileMetaData
 	auto &s_ele = file_meta_data->schema[next_schema_idx];
 	auto this_idx = next_schema_idx;
 
-	if (s_ele.__isset.repetition_type) {
-		if (s_ele.repetition_type != FieldRepetitionType::REQUIRED) {
-			max_define++;
-		}
-		if (s_ele.repetition_type == FieldRepetitionType::REPEATED) {
-			max_repeat++;
-		}
+	auto repetition_type = FieldRepetitionType::REQUIRED;
+	if (s_ele.__isset.repetition_type && this_idx > 0) {
+		repetition_type = s_ele.repetition_type;
+	}
+	if (repetition_type != FieldRepetitionType::REQUIRED) {
+		max_define++;
+	}
+	if (repetition_type == FieldRepetitionType::REPEATED) {
+		max_repeat++;
 	}
 
 	if (!s_ele.__isset.type) { // inner node
@@ -282,7 +292,7 @@ unique_ptr<ColumnReader> ParquetReader::CreateReaderRecursive(const FileMetaData
 		unique_ptr<ColumnReader> result;
 		LogicalType result_type;
 
-		bool is_repeated = s_ele.repetition_type == FieldRepetitionType::REPEATED;
+		bool is_repeated = repetition_type == FieldRepetitionType::REPEATED;
 		bool is_list = s_ele.__isset.converted_type && s_ele.converted_type == ConvertedType::LIST;
 		bool is_map = s_ele.__isset.converted_type && s_ele.converted_type == ConvertedType::MAP;
 		bool is_map_kv = s_ele.__isset.converted_type && s_ele.converted_type == ConvertedType::MAP_KEY_VALUE;
@@ -336,6 +346,17 @@ unique_ptr<ColumnReader> ParquetReader::CreateReaderRecursive(const FileMetaData
 			                                     std::move(element_reader));
 		}
 
+		// if this is a hive partition col, we should not read it at all but instead do a constant reader.
+		if (parquet_options.hive_partitioning && hive_map && depth == 1) {
+			auto lookup = hive_map->find(s_ele.name);
+			if (lookup != hive_map->end()) {
+				Value val = Value(lookup->second);
+				return make_unique<GeneratedConstantColumnReader>(*this, LogicalType::VARCHAR, SchemaElement(),
+				                                                  next_file_idx++, max_define, max_repeat, val);
+				;
+			}
+		}
+
 		// TODO check return value of derive type or should we only do this on read()
 		return ColumnReader::CreateReader(*this, DeriveLogicalType(s_ele), s_ele, next_file_idx++, max_define,
 		                                  max_repeat);
@@ -347,6 +368,13 @@ unique_ptr<ColumnReader> ParquetReader::CreateReader(const duckdb_parquet::forma
 	idx_t next_schema_idx = 0;
 	idx_t next_file_idx = 0;
 
+	if (file_meta_data->schema.empty()) {
+		throw IOException("Parquet reader: no schema elements found");
+	}
+	if (file_meta_data->schema[0].num_children == 0) {
+		throw IOException("Parquet reader: root schema element has no children");
+	}
+
 	auto ret = CreateReaderRecursive(file_meta_data, 0, 0, 0, next_schema_idx, next_file_idx);
 	D_ASSERT(next_schema_idx == file_meta_data->schema.size() - 1);
 	D_ASSERT(file_meta_data->row_groups.empty() || next_file_idx == file_meta_data->row_groups[0].columns.size());
@@ -373,9 +401,7 @@ unique_ptr<ColumnReader> ParquetReader::CreateReader(const duckdb_parquet::forma
 	}
 
 	if (parquet_options.hive_partitioning) {
-		auto res = HivePartitioning::Parse(file_name);
-
-		for (auto &partition : res) {
+		for (auto &partition : *hive_map) {
 			Value val = Value(partition.second);
 			root_struct_reader.child_readers.push_back(make_unique<GeneratedConstantColumnReader>(
 			    *this, LogicalType::VARCHAR, SchemaElement(), next_file_idx, 0, 0, val));
@@ -431,10 +457,16 @@ void ParquetReader::InitializeSchema(const vector<string> &expected_names, const
 
 	// Add generated constant column for filename
 	if (parquet_options.hive_partitioning) {
-		auto partitions = HivePartitioning::Parse(file_name);
-		for (auto &part : partitions) {
-			return_types.emplace_back(LogicalType::VARCHAR);
-			names.emplace_back(part.first);
+		for (auto &part : *hive_map) {
+			// We need to lookup the hive col in the cols of the file to avoid duplicating columns that are both
+			// in the file and the hive path
+			auto lookup =
+			    std::find_if(child_types.begin(), child_types.end(),
+			                 [&part](const std::pair<std::string, LogicalType> &x) { return x.first == part.first; });
+			if (lookup == child_types.end()) {
+				return_types.emplace_back(LogicalType::VARCHAR);
+				names.emplace_back(part.first);
+			}
 		}
 	}
 
@@ -523,16 +555,21 @@ ParquetReader::ParquetReader(ClientContext &context_p, string file_name_p, const
 	// If object cached is disabled
 	// or if this file has cached metadata
 	// or if the cached version already expired
-	auto last_modify_time = fs.GetLastModifiedTime(*file_handle);
 	if (!ObjectCache::ObjectCacheEnabled(context_p)) {
 		metadata = LoadMetadata(allocator, *file_handle, *file_opener);
 	} else {
+		auto last_modify_time = fs.GetLastModifiedTime(*file_handle);
 		metadata = ObjectCache::GetObjectCache(context_p).Get<ParquetFileMetadataCache>(file_name);
 		if (!metadata || (last_modify_time + 10 >= metadata->read_time)) {
 			metadata = LoadMetadata(allocator, *file_handle, *file_opener);
 			ObjectCache::GetObjectCache(context_p).Put(file_name, metadata);
 		}
 	}
+
+	if (parquet_options.hive_partitioning) {
+		hive_map = make_unique<std::map<string, string>>(HivePartitioning::Parse(file_name));
+	}
+
 	InitializeSchema(expected_names, expected_types_p, column_ids, initial_filename_p);
 }
 
