@@ -460,7 +460,7 @@ SimilarCatalogEntry CatalogSet::SimilarEntry(CatalogTransaction transaction, con
 	for (auto &kv : mapping) {
 		auto mapping_value = GetMapping(transaction, kv.first);
 		if (mapping_value && !mapping_value->deleted) {
-			auto ldist = StringUtil::LevenshteinDistance(kv.first, name);
+			auto ldist = StringUtil::SimilarityScore(kv.first, name);
 			if (ldist < result.distance) {
 				result.distance = ldist;
 				result.name = kv.first;
