@@ -607,7 +607,7 @@ static void InitializeFunctionPointers(ArrowAppendData &append_data, const Logic
 		break;
 	case LogicalTypeId::VARCHAR:
 	case LogicalTypeId::BLOB:
-	case LogicalTypeId::JSON:
+	case LogicalTypeId::BIT:
 		InitializeFunctionPointers<ArrowVarcharData<string_t>>(append_data);
 		break;
 	case LogicalTypeId::UUID:
