@@ -125,21 +125,13 @@ ColumnDataRowCollection::ColumnDataRowCollection(const ColumnDataCollection &col
 	}
 	// read all the chunks
 	ColumnDataScanState temp_scan_state;
-	collection.InitializeScan(temp_scan_state);
+	collection.InitializeScan(temp_scan_state, ColumnDataScanProperties::DISALLOW_ZERO_COPY);
 	while (true) {
 		auto chunk = make_unique<DataChunk>();
 		collection.InitializeScanChunk(*chunk);
 		if (!collection.Scan(temp_scan_state, *chunk)) {
 			break;
 		}
-		// we keep the BufferHandles that are needed for the materialized collection pinned in the supplied scan_state
-		auto &temp_handles = temp_scan_state.current_chunk_state.handles;
-		auto &scan_handles = scan_state.current_chunk_state.handles;
-		for (auto &temp_handle_pair : temp_handles) {
-			auto handle_copy =
-			    make_pair<uint32_t, BufferHandle>(scan_handles.size(), std::move(temp_handle_pair.second));
-			scan_state.current_chunk_state.handles.insert(std::move(handle_copy));
-		}
 		chunks.push_back(std::move(chunk));
 	}
 	// now create all of the column data rows
@@ -344,11 +336,21 @@ struct StringValueCopy : public BaseValueCopy<string_t> {
 	}
 };
 
+struct ConstListValueCopy : public BaseValueCopy<list_entry_t> {
+	using TYPE = list_entry_t;
+
+	static TYPE Operation(ColumnDataMetaData &meta_data, TYPE input) {
+		input.offset = meta_data.child_list_size;
+		return input;
+	}
+};
+
 struct ListValueCopy : public BaseValueCopy<list_entry_t> {
 	using TYPE = list_entry_t;
 
 	static TYPE Operation(ColumnDataMetaData &meta_data, TYPE input) {
-		input.offset += meta_data.child_list_size;
+		input.offset = meta_data.child_list_size;
+		meta_data.child_list_size += input.length;
 		return input;
 	}
 };
@@ -544,22 +546,20 @@ void ColumnDataCopy<string_t>(ColumnDataMetaData &meta_data, const UnifiedVector
 template <>
 void ColumnDataCopy<list_entry_t>(ColumnDataMetaData &meta_data, const UnifiedVectorFormat &source_data, Vector &source,
                                   idx_t offset, idx_t copy_count) {
+
 	auto &segment = meta_data.segment;
 
-	// first append the child entries of the list
 	auto &child_vector = ListVector::GetEntry(source);
-	idx_t child_list_size = ListVector::GetListSize(source);
 	auto &child_type = child_vector.GetType();
 
-	UnifiedVectorFormat child_vector_data;
-	child_vector.ToUnifiedFormat(child_list_size, child_vector_data);
-
 	if (!meta_data.GetVectorMetaData().child_index.IsValid()) {
 		auto child_index = segment.AllocateVector(child_type, meta_data.chunk_data, meta_data.state);
 		meta_data.GetVectorMetaData().child_index = meta_data.segment.AddChildIndex(child_index);
 	}
+
 	auto &child_function = meta_data.copy_function.child_functions[0];
 	auto child_index = segment.GetChildIndex(meta_data.GetVectorMetaData().child_index);
+
 	// figure out the current list size by traversing the set of child entries
 	idx_t current_list_size = 0;
 	auto current_child_index = child_index;
@@ -568,14 +568,37 @@ void ColumnDataCopy<list_entry_t>(ColumnDataMetaData &meta_data, const UnifiedVe
 		current_list_size += child_vdata.count;
 		current_child_index = child_vdata.next_data;
 	}
+
+	// set the child vector
+	UnifiedVectorFormat child_vector_data;
 	ColumnDataMetaData child_meta_data(child_function, meta_data, child_index);
-	// FIXME: appending the entire child list here is not required
-	// We can also scan the actual list entries required per the offset/copy_count
-	child_function.function(child_meta_data, child_vector_data, child_vector, 0, child_list_size);
+	auto info = ListVector::GetConsecutiveChildListInfo(source, offset, copy_count);
+
+	if (info.needs_slicing) {
+		SelectionVector sel(info.child_list_info.length);
+		ListVector::GetConsecutiveChildSelVector(source, sel, offset, copy_count);
+
+		auto sliced_child_vector = Vector(child_vector, sel, info.child_list_info.length);
+		sliced_child_vector.Flatten(info.child_list_info.length);
+		info.child_list_info.offset = 0;
+
+		sliced_child_vector.ToUnifiedFormat(info.child_list_info.length, child_vector_data);
+		child_function.function(child_meta_data, child_vector_data, sliced_child_vector, info.child_list_info.offset,
+		                        info.child_list_info.length);
+
+	} else {
+		child_vector.ToUnifiedFormat(info.child_list_info.length, child_vector_data);
+		child_function.function(child_meta_data, child_vector_data, child_vector, info.child_list_info.offset,
+		                        info.child_list_info.length);
+	}
 
 	// now copy the list entries
 	meta_data.child_list_size = current_list_size;
-	TemplatedColumnDataCopy<ListValueCopy>(meta_data, source_data, source, offset, copy_count);
+	if (info.is_constant) {
+		TemplatedColumnDataCopy<ConstListValueCopy>(meta_data, source_data, source, offset, copy_count);
+	} else {
+		TemplatedColumnDataCopy<ListValueCopy>(meta_data, source_data, source, offset, copy_count);
+	}
 }
 
 void ColumnDataCopyStruct(ColumnDataMetaData &meta_data, const UnifiedVectorFormat &source_data, Vector &source,
