@@ -7,7 +7,7 @@
 #include "duckdb/common/exception.hpp"
 #include "duckdb/common/types/null_value.hpp"
 #include "duckdb/common/types/chunk_collection.hpp"
-
+#include "duckdb/storage/segment/uncompressed.hpp"
 #include "duckdb/common/vector_operations/vector_operations.hpp"
 
 namespace duckdb {
@@ -59,6 +59,9 @@ void VectorOperations::Copy(const Vector &source_p, Vector &target, const Select
 			sel = ConstantVector::ZeroSelectionVector(copy_count, owned_sel);
 			finished = true;
 			break;
+		case VectorType::FSST_VECTOR:
+			finished = true;
+			break;
 		case VectorType::FLAT_VECTOR:
 			finished = true;
 			break;
@@ -87,12 +90,20 @@ void VectorOperations::Copy(const Vector &source_p, Vector &target, const Select
 			tmask.Set(target_offset + i, valid);
 		}
 	} else {
-		auto &smask = FlatVector::Validity(*source);
-		if (smask.IsMaskSet()) {
+		const ValidityMask *smask;
+		if (source->GetVectorType() == VectorType::FLAT_VECTOR) {
+			smask = &(FlatVector::Validity(*source));
+		} else if (source->GetVectorType() == VectorType::FSST_VECTOR) {
+			smask = &(FSSTVector::Validity(*source));
+		} else {
+			throw InternalException("Unsupported vector type in vector copy");
+		}
+
+		if (smask->IsMaskSet()) {
 			for (idx_t i = 0; i < copy_count; i++) {
 				auto idx = sel->get_index(source_offset + i);
 
-				if (smask.RowIsValid(idx)) {
+				if (smask->RowIsValid(idx)) {
 					// set valid
 					if (!tmask.AllValid()) {
 						tmask.SetValidUnsafe(target_offset + i);
@@ -111,6 +122,12 @@ void VectorOperations::Copy(const Vector &source_p, Vector &target, const Select
 
 	D_ASSERT(sel);
 
+	// For FSST Vectors we decompress instead of copying.
+	if (source->GetVectorType() == VectorType::FSST_VECTOR) {
+		FSSTVector::DecompressVector(*source, target, source_offset, target_offset, copy_count, sel);
+		return;
+	}
+
 	// now copy over the data
 	switch (source->GetType().InternalType()) {
 	case PhysicalType::BOOL:
