@@ -2,13 +2,14 @@
 #include "duckdb/planner/expression.hpp"
 #include "duckdb/planner/expression/bound_aggregate_expression.hpp"
 #include "duckdb/planner/expression/bound_reference_expression.hpp"
+#include "duckdb/common/algorithm.hpp"
 
 namespace duckdb {
 
 //! Shared information about a collection of distinct aggregates
 DistinctAggregateCollectionInfo::DistinctAggregateCollectionInfo(const vector<unique_ptr<Expression>> &aggregates,
                                                                  vector<idx_t> indices)
-    : indices(move(indices)), aggregates(aggregates) {
+    : indices(std::move(indices)), aggregates(aggregates) {
 	table_count = CreateTableIndexMap();
 
 	const idx_t aggregate_count = aggregates.size();
@@ -192,7 +193,7 @@ DistinctAggregateCollectionInfo::Create(vector<unique_ptr<Expression>> &aggregat
 	if (indices.empty()) {
 		return nullptr;
 	}
-	return make_unique<DistinctAggregateCollectionInfo>(aggregates, move(indices));
+	return make_unique<DistinctAggregateCollectionInfo>(aggregates, std::move(indices));
 }
 
 bool DistinctAggregateData::IsDistinct(idx_t index) const {
