@@ -2,6 +2,7 @@
 
 namespace duckdb {
 
+// ------- Helper functions for splitting string nested types  -------
 static bool IsNull(const char *buf, idx_t start_pos, Vector &child, idx_t row_idx) {
 	if (buf[start_pos] == 'N' && buf[start_pos + 1] == 'U' && buf[start_pos + 2] == 'L' && buf[start_pos + 3] == 'L') {
 		FlatVector::SetNull(child, row_idx, true);
@@ -16,46 +17,6 @@ inline static void SkipWhitespace(const char *buf, idx_t &pos, idx_t len) {
 	}
 }
 
-static idx_t StringTrim(const char *buf, idx_t &start_pos, idx_t pos) {
-	idx_t trailing_whitespace = 0;
-	while (StringUtil::CharacterIsSpace(buf[pos - trailing_whitespace - 1])) {
-		trailing_whitespace++;
-	}
-	if ((buf[start_pos] == '"' && buf[pos - trailing_whitespace - 1] == '"') ||
-	    (buf[start_pos] == '\'' && buf[pos - trailing_whitespace - 1] == '\'')) {
-		start_pos++;
-		trailing_whitespace++;
-	}
-	return (pos - trailing_whitespace);
-}
-
-struct CountPartOperation {
-	idx_t count = 0;
-
-	void HandleValue(const char *buf, idx_t start_pos, idx_t pos) {
-		count++;
-	}
-};
-
-struct SplitStringOperation {
-	SplitStringOperation(string_t *child_data, idx_t &child_start, Vector &child)
-	    : child_data(child_data), child_start(child_start), child(child) {
-	}
-
-	string_t *child_data;
-	idx_t &child_start;
-	Vector &child;
-
-	void HandleValue(const char *buf, idx_t start_pos, idx_t pos) {
-		if ((pos - start_pos) == 4 && IsNull(buf, start_pos, child, child_start)) {
-			child_start++;
-			return;
-		}
-		child_data[child_start] = StringVector::AddString(child, buf + start_pos, pos - start_pos);
-		child_start++;
-	}
-};
-
 static bool SkipToCloseQuotes(idx_t &pos, const char *buf, idx_t &len) {
 	char quote = buf[pos];
 	pos++;
@@ -97,8 +58,53 @@ static bool SkipToClose(idx_t &idx, const char *buf, idx_t &len, idx_t &lvl, cha
 	return false;
 }
 
+static idx_t StringTrim(const char *buf, idx_t &start_pos, idx_t pos) {
+	idx_t trailing_whitespace = 0;
+	while (StringUtil::CharacterIsSpace(buf[pos - trailing_whitespace - 1])) {
+		trailing_whitespace++;
+	}
+	if ((buf[start_pos] == '"' && buf[pos - trailing_whitespace - 1] == '"') ||
+	    (buf[start_pos] == '\'' && buf[pos - trailing_whitespace - 1] == '\'')) {
+		start_pos++;
+		trailing_whitespace++;
+	}
+	return (pos - trailing_whitespace);
+}
+
+struct CountPartOperation {
+	idx_t count = 0;
+
+	bool HandleKey(const char *buf, idx_t start_pos, idx_t pos) {
+		count++;
+		return true;
+	}
+	void HandleValue(const char *buf, idx_t start_pos, idx_t pos) {
+		count++;
+	}
+};
+
+// ------- LIST SPLIT -------
+struct SplitStringListOperation {
+	SplitStringListOperation(string_t *child_data, idx_t &child_start, Vector &child)
+	    : child_data(child_data), child_start(child_start), child(child) {
+	}
+
+	string_t *child_data;
+	idx_t &child_start;
+	Vector &child;
+
+	void HandleValue(const char *buf, idx_t start_pos, idx_t pos) {
+		if ((pos - start_pos) == 4 && IsNull(buf, start_pos, child, child_start)) {
+			child_start++;
+			return;
+		}
+		child_data[child_start] = StringVector::AddString(child, buf + start_pos, pos - start_pos);
+		child_start++;
+	}
+};
+
 template <class OP>
-static bool SplitStringifiedListInternal(const string_t &input, OP &state) {
+static bool SplitStringListInternal(const string_t &input, OP &state) {
 	const char *buf = input.GetDataUnsafe();
 	idx_t len = input.GetSize();
 	idx_t lvl = 1;
@@ -143,19 +149,121 @@ static bool SplitStringifiedListInternal(const string_t &input, OP &state) {
 	return (pos == len && lvl == 0);
 }
 
-bool VectorStringToList::SplitStringifiedList(const string_t &input, string_t *child_data, idx_t &child_start,
-                                              Vector &child) {
-	SplitStringOperation state(child_data, child_start, child);
-	return SplitStringifiedListInternal<SplitStringOperation>(input, state);
+bool VectorStringToList::SplitStringList(const string_t &input, string_t *child_data, idx_t &child_start,
+                                         Vector &child) {
+	SplitStringListOperation state(child_data, child_start, child);
+	return SplitStringListInternal<SplitStringListOperation>(input, state);
 }
 
-idx_t VectorStringToList::CountParts(const string_t &input) {
+idx_t VectorStringToList::CountPartsList(const string_t &input) {
 	CountPartOperation state;
-	SplitStringifiedListInternal<CountPartOperation>(input, state);
+	SplitStringListInternal<CountPartOperation>(input, state);
 	return state.count;
 }
 
-static bool FindKey(const char *buf, idx_t len, idx_t &pos) {
+// ------- MAP SPLIT -------
+struct SplitStringMapOperation {
+	SplitStringMapOperation(string_t *child_key_data, string_t *child_val_data, idx_t &child_start, Vector &varchar_key,
+	                        Vector &varchar_val)
+	    : child_key_data(child_key_data), child_val_data(child_val_data), child_start(child_start),
+	      varchar_key(varchar_key), varchar_val(varchar_val) {
+	}
+
+	string_t *child_key_data;
+	string_t *child_val_data;
+	idx_t &child_start;
+	Vector &varchar_key;
+	Vector &varchar_val;
+
+	bool HandleKey(const char *buf, idx_t start_pos, idx_t pos) {
+		if ((pos - start_pos) == 4 && IsNull(buf, start_pos, varchar_key, child_start)) {
+			FlatVector::SetNull(varchar_val, child_start, true);
+			child_start++;
+			return false;
+		}
+		child_key_data[child_start] = StringVector::AddString(varchar_key, buf + start_pos, pos - start_pos);
+		return true;
+	}
+
+	void HandleValue(const char *buf, idx_t start_pos, idx_t pos) {
+		if ((pos - start_pos) == 4 && IsNull(buf, start_pos, varchar_val, child_start)) {
+			child_start++;
+			return;
+		}
+		child_val_data[child_start] = StringVector::AddString(varchar_val, buf + start_pos, pos - start_pos);
+		child_start++;
+	}
+};
+
+template <class OP>
+static bool FindKeyOrValueMap(const char *buf, idx_t len, idx_t &pos, OP &state, bool key) {
+	auto start_pos = pos;
+	idx_t lvl = 0;
+	while (pos < len) {
+		if (buf[pos] == '"' || buf[pos] == '\'') {
+			SkipToCloseQuotes(pos, buf, len);
+		} else if (buf[pos] == '{') {
+			SkipToClose(pos, buf, len, lvl, '}');
+		} else if (buf[pos] == '[') {
+			SkipToClose(pos, buf, len, lvl, ']');
+		} else if (key && buf[pos] == '=') {
+			idx_t end_pos = StringTrim(buf, start_pos, pos);
+			return state.HandleKey(buf, start_pos, end_pos); // put string in KEY_child_vector
+		} else if (!key && (buf[pos] == ',' || buf[pos] == '}')) {
+			idx_t end_pos = StringTrim(buf, start_pos, pos);
+			state.HandleValue(buf, start_pos, end_pos); // put string in VALUE_child_vector
+			return true;
+		}
+		pos++;
+	}
+	return false;
+}
+
+template <class OP>
+static bool SplitStringMapInternal(const string_t &input, OP &state) {
+	const char *buf = input.GetDataUnsafe();
+	idx_t len = input.GetSize();
+	idx_t pos = 0;
+
+	SkipWhitespace(buf, pos, len);
+	if (pos == len || buf[pos] != '{') {
+		return false;
+	}
+	SkipWhitespace(buf, ++pos, len);
+	if (pos == len) {
+		return false;
+	}
+	if (buf[pos] == '}') {
+		SkipWhitespace(buf, ++pos, len);
+		return (pos == len);
+	}
+	while (pos < len) {
+		if (!FindKeyOrValueMap(buf, len, pos, state, true)) {
+			return false;
+		}
+		SkipWhitespace(buf, ++pos, len);
+		if (!FindKeyOrValueMap(buf, len, pos, state, false)) {
+			return false;
+		}
+		SkipWhitespace(buf, ++pos, len);
+	}
+	return true;
+}
+
+bool VectorStringToMap::SplitStringMap(const string_t &input, string_t *child_key_data, string_t *child_val_data,
+                                       idx_t &child_start, Vector &varchar_key, Vector &varchar_val) {
+	SplitStringMapOperation state(child_key_data, child_val_data, child_start, varchar_key, varchar_val);
+	return SplitStringMapInternal<SplitStringMapOperation>(input, state);
+}
+
+idx_t VectorStringToMap::CountPartsMap(const string_t &input) {
+	CountPartOperation state;
+	SplitStringMapInternal<CountPartOperation>(input, state);
+	return state.count;
+}
+
+// ------- STRUCT SPLIT -------
+static bool FindKeyStruct(const char *buf, idx_t len, idx_t &pos) {
 	while (pos < len) {
 		if (buf[pos] == ':') {
 			return true;
@@ -165,8 +273,8 @@ static bool FindKey(const char *buf, idx_t len, idx_t &pos) {
 	return false;
 }
 
-static bool FindValue(const char *buf, idx_t len, idx_t &pos, Vector &varchar_child, idx_t &row_idx,
-                      ValidityMask *child_mask) {
+static bool FindValueStruct(const char *buf, idx_t len, idx_t &pos, Vector &varchar_child, idx_t &row_idx,
+                            ValidityMask *child_mask) {
 	auto start_pos = pos;
 	idx_t lvl = 0;
 	while (pos < len) {
@@ -209,7 +317,7 @@ bool VectorStringToStruct::SplitStruct(string_t &input, std::vector<std::unique_
 	} else {
 		while (pos < len) {
 			auto key_start = pos;
-			if (!FindKey(buf, len, pos)) {
+			if (!FindKeyStruct(buf, len, pos)) {
 				return false;
 			}
 			auto key_end = StringTrim(buf, key_start, pos);
@@ -221,7 +329,7 @@ bool VectorStringToStruct::SplitStruct(string_t &input, std::vector<std::unique_
 			}
 			child_idx = it->second;
 			SkipWhitespace(buf, ++pos, len);
-			if (!FindValue(buf, len, pos, *varchar_vectors[child_idx], row_idx, child_masks[child_idx])) {
+			if (!FindValueStruct(buf, len, pos, *varchar_vectors[child_idx], row_idx, child_masks[child_idx])) {
 				return false;
 			}
 			SkipWhitespace(buf, ++pos, len);
