@@ -22,12 +22,11 @@ string MacroFunction::ValidateArguments(MacroFunction &macro_def, const string &
 
 	// separate positional and default arguments
 	for (auto &arg : function_expr.children) {
-		if ((arg->type == ExpressionType::VALUE_CONSTANT || arg->type == ExpressionType::VALUE_PARAMETER) &&
-		    !arg->alias.empty()) {
+		if (!arg->alias.empty()) {
 			// default argument
-			if (macro_def.default_parameters.find(arg->alias) == macro_def.default_parameters.end()) {
+			if (!macro_def.default_parameters.count(arg->alias)) {
 				return StringUtil::Format("Macro %s does not have default parameter %s!", name, arg->alias);
-			} else if (defaults.find(arg->alias) != defaults.end()) {
+			} else if (defaults.count(arg->alias)) {
 				return StringUtil::Format("Duplicate default parameters %s!", arg->alias);
 			}
 			defaults[arg->alias] = std::move(arg);
@@ -57,10 +56,13 @@ string MacroFunction::ValidateArguments(MacroFunction &macro_def, const string &
 		return error;
 	}
 
-	// fill in default value where this was not supplied
+	// Add the default values for parameters that have defaults, that were not explicitly assigned to
 	for (auto it = macro_def.default_parameters.begin(); it != macro_def.default_parameters.end(); it++) {
-		if (defaults.find(it->first) == defaults.end()) {
-			defaults[it->first] = it->second->Copy();
+		auto &parameter_name = it->first;
+		auto &parameter_default = it->second;
+		if (!defaults.count(parameter_name)) {
+			// This parameter was not set yet, set it with the default value
+			defaults[parameter_name] = parameter_default->Copy();
 		}
 	}
 
