@@ -1,6 +1,7 @@
 #include "duckdb/function/scalar/string_functions.hpp"
 #include "duckdb/function/scalar/blob_functions.hpp"
 #include "duckdb/function/scalar/uuid_functions.hpp"
+#include "duckdb/function/scalar/bit_functions.hpp"
 
 namespace duckdb {
 
@@ -33,6 +34,7 @@ void BuiltinFunctions::RegisterStringFunctions() {
 	Register<UnicodeFun>();
 	Register<NFCNormalizeFun>();
 	Register<StringSplitFun>();
+	Register<BarFun>();
 	Register<ASCII>();
 	Register<CHR>();
 	Register<MismatchesFun>();
@@ -44,6 +46,11 @@ void BuiltinFunctions::RegisterStringFunctions() {
 	Register<Base64Fun>();
 	Register<EncodeFun>();
 
+	// bit functions
+	Register<GetBitFun>();
+	Register<SetBitFun>();
+	Register<BitPositionFun>();
+
 	// uuid functions
 	Register<UUIDFun>();
 }
