@@ -5,7 +5,7 @@
 #include "duckdb/main/client_data.hpp"
 #include "duckdb/planner/expression/bound_function_expression.hpp"
 #include "duckdb/catalog/catalog_entry/aggregate_function_catalog_entry.hpp"
-#include "duckdb/transaction/transaction.hpp"
+#include "duckdb/transaction/duck_transaction.hpp"
 #include "duckdb/main/database_manager.hpp"
 
 namespace duckdb {
@@ -22,6 +22,12 @@ static void CurrentSchemaFunction(DataChunk &input, ExpressionState &state, Vect
 	result.Reference(val);
 }
 
+// current_database
+static void CurrentDatabaseFunction(DataChunk &input, ExpressionState &state, Vector &result) {
+	Value val(DatabaseManager::GetDefaultDatabase(state.GetContext()));
+	result.Reference(val);
+}
+
 // current_schemas
 static void CurrentSchemasFunction(DataChunk &input, ExpressionState &state, Vector &result) {
 	if (!input.AllConstant()) {
@@ -47,7 +53,7 @@ static void CurrentSchemasFunction(DataChunk &input, ExpressionState &state, Vec
 static void TransactionIdCurrent(DataChunk &input, ExpressionState &state, Vector &result) {
 	auto &context = state.GetContext();
 	auto &catalog = Catalog::GetCatalog(context, DatabaseManager::GetDefaultDatabase(context));
-	auto &transaction = Transaction::Get(context, catalog);
+	auto &transaction = DuckTransaction::Get(context, catalog);
 	auto val = Value::BIGINT(transaction.start_time);
 	result.Reference(val);
 }
@@ -65,6 +71,7 @@ void SystemFun::RegisterFunction(BuiltinFunctions &set) {
 	current_query.side_effects = FunctionSideEffects::HAS_SIDE_EFFECTS;
 	set.AddFunction(current_query);
 	set.AddFunction(ScalarFunction("current_schema", {}, LogicalType::VARCHAR, CurrentSchemaFunction));
+	set.AddFunction(ScalarFunction("current_database", {}, LogicalType::VARCHAR, CurrentDatabaseFunction));
 	set.AddFunction(
 	    ScalarFunction("current_schemas", {LogicalType::BOOLEAN}, varchar_list_type, CurrentSchemasFunction));
 	set.AddFunction(ScalarFunction("txid_current", {}, LogicalType::BIGINT, TransactionIdCurrent));
