@@ -14,7 +14,7 @@
 namespace duckdb {
 
 TableMacroFunction::TableMacroFunction(unique_ptr<QueryNode> query_node)
-    : MacroFunction(MacroType::TABLE_MACRO), query_node(move(query_node)) {
+    : MacroFunction(MacroType::TABLE_MACRO), query_node(std::move(query_node)) {
 }
 
 TableMacroFunction::TableMacroFunction(void) : MacroFunction(MacroType::TABLE_MACRO) {
@@ -24,7 +24,7 @@ unique_ptr<MacroFunction> TableMacroFunction::Copy() {
 	auto result = make_unique<TableMacroFunction>();
 	result->query_node = query_node->Copy();
 	this->CopyProperties(*result);
-	return move(result);
+	return std::move(result);
 }
 
 string TableMacroFunction::ToSQL(const string &schema, const string &name) {
