@@ -22,6 +22,10 @@ struct CreateTableFunctionInfo;
 
 //! A table function in the catalog
 class TableFunctionCatalogEntry : public StandardEntry {
+public:
+	static constexpr const CatalogType Type = CatalogType::TABLE_FUNCTION_ENTRY;
+	static constexpr const char *Name = "table function";
+
 public:
 	TableFunctionCatalogEntry(Catalog *catalog, SchemaCatalogEntry *schema, CreateTableFunctionInfo *info);
 
