@@ -16,6 +16,10 @@ namespace duckdb {
 
 //! A macro function in the catalog
 class TableMacroCatalogEntry : public MacroCatalogEntry {
+public:
+	static constexpr const CatalogType Type = CatalogType::TABLE_MACRO_ENTRY;
+	static constexpr const char *Name = "table macro function";
+
 public:
 	TableMacroCatalogEntry(Catalog *catalog, SchemaCatalogEntry *schema, CreateMacroInfo *info);
 
