@@ -35,7 +35,7 @@ public:
 
 	//! helper function to get the HTTP
 	static HTTPStats *TryGetStats(FileOpener *opener) {
-		auto client_context = opener->TryGetClientContext();
+		auto client_context = FileOpener::TryGetClientContext(opener);
 		if (client_context) {
 			return client_context->client_data->http_stats.get();
 		}
