@@ -14,13 +14,14 @@
 namespace duckdb {
 
 struct AggregateObject;
+struct AggregateFilterData;
 class DataChunk;
 class RowLayout;
 class RowDataCollection;
 struct SelectionVector;
 class StringHeap;
 class Vector;
-struct VectorData;
+struct UnifiedVectorFormat;
 
 // RowOperations contains a set of operations that operate on data using a RowLayout
 struct RowOperations {
@@ -34,7 +35,8 @@ struct RowOperations {
 	//! update - aligned addresses
 	static void UpdateStates(AggregateObject &aggr, Vector &addresses, DataChunk &payload, idx_t arg_idx, idx_t count);
 	//! filtered update - aligned addresses
-	static void UpdateFilteredStates(AggregateObject &aggr, Vector &addresses, DataChunk &payload, idx_t arg_idx);
+	static void UpdateFilteredStates(AggregateFilterData &filter_data, AggregateObject &aggr, Vector &addresses,
+	                                 DataChunk &payload, idx_t arg_idx);
 	//! combine - unaligned addresses, updated
 	static void CombineStates(RowLayout &layout, Vector &sources, Vector &targets, idx_t count);
 	//! finalize - unaligned addresses, updated
@@ -44,11 +46,14 @@ struct RowOperations {
 	// Read/Write Operators
 	//===--------------------------------------------------------------------===//
 	//! Scatter group data to the rows. Initialises the ValidityMask.
-	static void Scatter(DataChunk &columns, VectorData col_data[], const RowLayout &layout, Vector &rows,
+	static void Scatter(DataChunk &columns, UnifiedVectorFormat col_data[], const RowLayout &layout, Vector &rows,
 	                    RowDataCollection &string_heap, const SelectionVector &sel, idx_t count);
 	//! Gather a single column.
+	//! If heap_ptr is not null, then the data is assumed to contain swizzled pointers,
+	//! which will be unswizzled in memory.
 	static void Gather(Vector &rows, const SelectionVector &row_sel, Vector &col, const SelectionVector &col_sel,
-	                   const idx_t count, const idx_t col_offset, const idx_t col_no, const idx_t build_size = 0);
+	                   const idx_t count, const RowLayout &layout, const idx_t col_no, const idx_t build_size = 0,
+	                   data_ptr_t heap_ptr = nullptr);
 	//! Full Scan an entire columns
 	static void FullScanColumn(const RowLayout &layout, Vector &rows, Vector &col, idx_t count, idx_t col_idx);
 
@@ -60,7 +65,7 @@ struct RowOperations {
 	//! Returns the number of matches remaining in the selection.
 	using Predicates = vector<ExpressionType>;
 
-	static idx_t Match(DataChunk &columns, VectorData col_data[], const RowLayout &layout, Vector &rows,
+	static idx_t Match(DataChunk &columns, UnifiedVectorFormat col_data[], const RowLayout &layout, Vector &rows,
 	                   const Predicates &predicates, SelectionVector &sel, idx_t count, SelectionVector *no_match,
 	                   idx_t &no_match_count);
 
@@ -71,15 +76,15 @@ struct RowOperations {
 	static void ComputeEntrySizes(Vector &v, idx_t entry_sizes[], idx_t vcount, idx_t ser_count,
 	                              const SelectionVector &sel, idx_t offset = 0);
 	//! Compute the entry sizes of vector data with variable size type (used before building heap buffer space).
-	static void ComputeEntrySizes(Vector &v, VectorData &vdata, idx_t entry_sizes[], idx_t vcount, idx_t ser_count,
-	                              const SelectionVector &sel, idx_t offset = 0);
+	static void ComputeEntrySizes(Vector &v, UnifiedVectorFormat &vdata, idx_t entry_sizes[], idx_t vcount,
+	                              idx_t ser_count, const SelectionVector &sel, idx_t offset = 0);
 	//! Scatter vector with variable size type to the heap.
 	static void HeapScatter(Vector &v, idx_t vcount, const SelectionVector &sel, idx_t ser_count, idx_t col_idx,
 	                        data_ptr_t *key_locations, data_ptr_t *validitymask_locations, idx_t offset = 0);
 	//! Scatter vector data with variable size type to the heap.
-	static void HeapScatterVData(VectorData &vdata, PhysicalType type, const SelectionVector &sel, idx_t ser_count,
-	                             idx_t col_idx, data_ptr_t *key_locations, data_ptr_t *validitymask_locations,
-	                             idx_t offset = 0);
+	static void HeapScatterVData(UnifiedVectorFormat &vdata, PhysicalType type, const SelectionVector &sel,
+	                             idx_t ser_count, idx_t col_idx, data_ptr_t *key_locations,
+	                             data_ptr_t *validitymask_locations, idx_t offset = 0);
 	//! Gather a single column with variable size type from the heap.
 	static void HeapGather(Vector &v, const idx_t &vcount, const SelectionVector &sel, const idx_t &col_idx,
 	                       data_ptr_t key_locations[], data_ptr_t validitymask_locations[]);
@@ -99,7 +104,14 @@ struct RowOperations {
 	static void SwizzleColumns(const RowLayout &layout, const data_ptr_t base_row_ptr, const idx_t count);
 	//! Swizzles the base pointer of each row to offset within heap block
 	static void SwizzleHeapPointer(const RowLayout &layout, data_ptr_t row_ptr, const data_ptr_t heap_base_ptr,
-	                               const idx_t count);
+	                               const idx_t count, const idx_t base_offset = 0);
+	//! Copies 'count' heap rows that are pointed to by the rows at 'row_ptr' to 'heap_ptr' and swizzles the pointers
+	static void CopyHeapAndSwizzle(const RowLayout &layout, data_ptr_t row_ptr, const data_ptr_t heap_base_ptr,
+	                               data_ptr_t heap_ptr, const idx_t count);
+
+	//! Unswizzles the base offset within heap block the rows to pointers
+	static void UnswizzleHeapPointer(const RowLayout &layout, const data_ptr_t base_row_ptr,
+	                                 const data_ptr_t base_heap_ptr, const idx_t count);
 	//! Unswizzles all offsets back to pointers
 	static void UnswizzlePointers(const RowLayout &layout, const data_ptr_t base_row_ptr,
 	                              const data_ptr_t base_heap_ptr, const idx_t count);
