@@ -12,6 +12,20 @@
 
 namespace duckdb {
 
+struct dtime_t;
+struct date_t;
+struct timestamp_t;
+
+struct interval_t {
+	int32_t months;
+	int32_t days;
+	int64_t micros;
+
+	inline bool operator==(const interval_t &rhs) const {
+		return this->days == rhs.days && this->months == rhs.months && this->micros == rhs.micros;
+	}
+};
+
 //! The Interval class is a static class that holds helper functions for the Interval
 //! type.
 class Interval {
