@@ -12,16 +12,22 @@
 #include "duckdb/planner/expression.hpp"
 #include "duckdb/planner/parsed_data/bound_create_table_info.hpp"
 #include "duckdb/common/index_vector.hpp"
+#include "duckdb/parser/statement/insert_statement.hpp"
 
 namespace duckdb {
 
+class InsertLocalState;
+
 //! Physically insert a set of data into a table
 class PhysicalInsert : public PhysicalOperator {
 public:
 	//! INSERT INTO
 	PhysicalInsert(vector<LogicalType> types, TableCatalogEntry *table, physical_index_vector_t<idx_t> column_index_map,
-	               vector<unique_ptr<Expression>> bound_defaults, idx_t estimated_cardinality, bool return_chunk,
-	               bool parallel);
+	               vector<unique_ptr<Expression>> bound_defaults, vector<unique_ptr<Expression>> set_expressions,
+	               vector<PhysicalIndex> set_columns, vector<LogicalType> set_types, idx_t estimated_cardinality,
+	               bool return_chunk, bool parallel, OnConflictAction action_type,
+	               unique_ptr<Expression> on_conflict_condition, unique_ptr<Expression> do_update_condition,
+	               unordered_set<column_t> on_conflict_filter, vector<column_t> columns_to_fetch);
 	//! CREATE TABLE AS
 	PhysicalInsert(LogicalOperator &op, SchemaCatalogEntry *schema, unique_ptr<BoundCreateTableInfo> info,
 	               idx_t estimated_cardinality, bool parallel);
@@ -43,6 +49,27 @@ public:
 	//! Whether or not the INSERT can be executed in parallel
 	//! This insert is not order preserving if executed in parallel
 	bool parallel;
+	// Which action to perform on conflict
+	OnConflictAction action_type;
+
+	// The DO UPDATE set expressions, if 'action_type' is UPDATE
+	vector<unique_ptr<Expression>> set_expressions;
+	// Which columns are targeted by the set expressions
+	vector<PhysicalIndex> set_columns;
+	// The types of the columns targeted by a SET expression
+	vector<LogicalType> set_types;
+
+	// Condition for the ON CONFLICT clause
+	unique_ptr<Expression> on_conflict_condition;
+	// Condition for the DO UPDATE clause
+	unique_ptr<Expression> do_update_condition;
+	// The column ids to apply the ON CONFLICT on
+	unordered_set<column_t> conflict_target;
+
+	// Column ids from the original table to fetch
+	vector<column_t> columns_to_fetch;
+	// Matching types to the column ids to fetch
+	vector<LogicalType> types_to_fetch;
 
 public:
 	// Source interface
@@ -74,6 +101,14 @@ public:
 	static void ResolveDefaults(TableCatalogEntry *table, DataChunk &chunk,
 	                            const physical_index_vector_t<idx_t> &column_index_map,
 	                            ExpressionExecutor &defaults_executor, DataChunk &result);
+
+protected:
+	void CombineExistingAndInsertTuples(DataChunk &result, DataChunk &scan_chunk, DataChunk &input_chunk,
+	                                    ClientContext &client) const;
+	void OnConflictHandling(TableCatalogEntry *table, ExecutionContext &context, InsertLocalState &lstate) const;
+	void PerformOnConflictAction(ExecutionContext &context, DataChunk &chunk, TableCatalogEntry *table,
+	                             Vector &row_ids) const;
+	void RegisterUpdatedRows(InsertLocalState &lstate, const Vector &row_ids, idx_t count) const;
 };
 
 } // namespace duckdb
