@@ -14,10 +14,9 @@ namespace duckdb {
 
 class PerfectAggregateHashTable : public BaseAggregateHashTable {
 public:
-	PerfectAggregateHashTable(Allocator &allocator, BufferManager &buffer_manager,
-	                          const vector<LogicalType> &group_types, vector<LogicalType> payload_types_p,
-	                          vector<AggregateObject> aggregate_objects, vector<Value> group_minima,
-	                          vector<idx_t> required_bits);
+	PerfectAggregateHashTable(ClientContext &context, Allocator &allocator, const vector<LogicalType> &group_types,
+	                          vector<LogicalType> payload_types_p, vector<AggregateObject> aggregate_objects,
+	                          vector<Value> group_minima, vector<idx_t> required_bits);
 	~PerfectAggregateHashTable() override;
 
 public:
