@@ -13,15 +13,15 @@
 namespace duckdb {
 
 class ClientContext;
-class TableFunctionRef;
+class TableRef;
 
 struct ReplacementScanData {
 	virtual ~ReplacementScanData() {
 	}
 };
 
-typedef unique_ptr<TableFunctionRef> (*replacement_scan_t)(ClientContext &context, const string &table_name,
-                                                           ReplacementScanData *data);
+typedef unique_ptr<TableRef> (*replacement_scan_t)(ClientContext &context, const string &table_name,
+                                                   ReplacementScanData *data);
 
 //! Replacement table scans are automatically attempted when a table name cannot be found in the schema
 //! This allows you to do e.g. SELECT * FROM 'filename.csv', and automatically convert this into a CSV scan
