@@ -10,6 +10,7 @@
 
 #include "duckdb/function/scalar_function.hpp"
 #include "duckdb/function/function_set.hpp"
+#include "duckdb/function/built_in_functions.hpp"
 
 namespace duckdb {
 
@@ -61,6 +62,10 @@ struct StrpTimeFun {
 	static void RegisterFunction(BuiltinFunctions &set);
 };
 
+struct TimeBucketFun {
+	static void RegisterFunction(BuiltinFunctions &set);
+};
+
 struct ToIntervalFun {
 	static void RegisterFunction(BuiltinFunctions &set);
 };
