@@ -88,7 +88,8 @@ struct LengthFun {
 
 struct LikeFun {
 	static void RegisterFunction(BuiltinFunctions &set);
-	DUCKDB_API static bool Glob(const char *s, idx_t slen, const char *pattern, idx_t plen);
+	DUCKDB_API static bool Glob(const char *s, idx_t slen, const char *pattern, idx_t plen,
+	                            bool allow_question_mark = true);
 };
 
 struct LikeEscapeFun {
