@@ -8,18 +8,15 @@
 
 #pragma once
 
-#include "duckdb/parallel/event.hpp"
-#include "duckdb/parallel/pipeline.hpp"
+#include "duckdb/parallel/base_pipeline_event.hpp"
 
 namespace duckdb {
 
-class PipelineEvent : public Event {
+//! A PipelineEvent is responsible for scheduling a pipeline
+class PipelineEvent : public BasePipelineEvent {
 public:
 	PipelineEvent(shared_ptr<Pipeline> pipeline);
 
-	//! The pipeline that this event belongs to
-	shared_ptr<Pipeline> pipeline;
-
 public:
 	void Schedule() override;
 	void FinishEvent() override;
