@@ -11,9 +11,38 @@
 #include "duckdb/parser/parsed_expression.hpp"
 #include "duckdb/parser/statement/select_statement.hpp"
 #include "duckdb/parser/query_node.hpp"
+#include "duckdb/parser/statement/update_statement.hpp"
 
 namespace duckdb {
 class ExpressionListRef;
+class UpdateSetInfo;
+
+enum class OnConflictAction : uint8_t {
+	THROW,
+	NOTHING,
+	UPDATE,
+	REPLACE // Only used in transform/bind step, changed to UPDATE later
+};
+
+class OnConflictInfo {
+public:
+	OnConflictInfo();
+
+public:
+	unique_ptr<OnConflictInfo> Copy() const;
+
+public:
+	OnConflictAction action_type;
+
+	vector<string> indexed_columns;
+	//! The SET information (if action_type == UPDATE)
+	unique_ptr<UpdateSetInfo> set_info;
+	//! The condition determining whether we apply the DO .. for conflicts that arise
+	unique_ptr<ParsedExpression> condition;
+
+protected:
+	OnConflictInfo(const OnConflictInfo &other);
+};
 
 class InsertStatement : public SQLStatement {
 public:
@@ -34,6 +63,9 @@ public:
 	//! keep track of optional returningList if statement contains a RETURNING keyword
 	vector<unique_ptr<ParsedExpression>> returning_list;
 
+	unique_ptr<OnConflictInfo> on_conflict_info;
+	unique_ptr<TableRef> table_ref;
+
 	//! CTEs
 	CommonTableExpressionMap cte_map;
 
@@ -41,6 +73,7 @@ protected:
 	InsertStatement(const InsertStatement &other);
 
 public:
+	static string OnConflictActionToString(OnConflictAction action);
 	string ToString() const override;
 	unique_ptr<SQLStatement> Copy() const override;
 
