@@ -16,17 +16,34 @@
 
 namespace duckdb {
 
+class UpdateSetInfo {
+public:
+	UpdateSetInfo();
+
+public:
+	unique_ptr<UpdateSetInfo> Copy() const;
+
+public:
+	// The condition that needs to be met to perform the update
+	unique_ptr<ParsedExpression> condition;
+	// The columns to update
+	vector<string> columns;
+	// The set expressions to execute
+	vector<unique_ptr<ParsedExpression>> expressions;
+
+protected:
+	UpdateSetInfo(const UpdateSetInfo &other);
+};
+
 class UpdateStatement : public SQLStatement {
 public:
 	UpdateStatement();
 
-	unique_ptr<ParsedExpression> condition;
 	unique_ptr<TableRef> table;
 	unique_ptr<TableRef> from_table;
-	vector<string> columns;
-	vector<unique_ptr<ParsedExpression>> expressions;
 	//! keep track of optional returningList if statement contains a RETURNING keyword
 	vector<unique_ptr<ParsedExpression>> returning_list;
+	unique_ptr<UpdateSetInfo> set_info;
 	//! CTEs
 	CommonTableExpressionMap cte_map;
 
