@@ -20,7 +20,7 @@ class LogicalExplain : public LogicalOperator {
 public:
 	LogicalExplain(unique_ptr<LogicalOperator> plan, ExplainType explain_type)
 	    : LogicalOperator(LogicalOperatorType::LOGICAL_EXPLAIN), explain_type(explain_type) {
-		children.push_back(move(plan));
+		children.push_back(std::move(plan));
 	}
 
 	ExplainType explain_type;
