@@ -27,9 +27,11 @@ public:
 
 public:
 	vector<ColumnBinding> GetColumnBindings() override;
-
 	idx_t EstimateCardinality(ClientContext &context) override;
 
+	void Serialize(FieldWriter &writer) const override;
+	static unique_ptr<LogicalOperator> Deserialize(LogicalDeserializationState &state, FieldReader &reader);
+
 protected:
 	void ResolveTypes() override;
 };
