@@ -13,6 +13,7 @@
 #include "duckdb/storage/data_table.hpp"
 #include "duckdb/storage/table_io_manager.hpp"
 #include "duckdb/storage/write_ahead_log.hpp"
+#include "duckdb/storage/database_size.hpp"
 
 namespace duckdb {
 class BlockManager;
@@ -22,15 +23,6 @@ class DatabaseInstance;
 class TransactionManager;
 class TableCatalogEntry;
 
-struct DatabaseSize {
-	idx_t total_blocks = 0;
-	idx_t block_size = 0;
-	idx_t free_blocks = 0;
-	idx_t used_blocks = 0;
-	idx_t bytes = 0;
-	idx_t wal_size = 0;
-};
-
 class StorageCommitState {
 public:
 	// Destruction of this object, without prior call to FlushCommit,
