@@ -12,13 +12,15 @@
 #include "duckdb/storage/storage_lock.hpp"
 #include "duckdb/storage/buffer/buffer_handle.hpp"
 #include "duckdb/common/vector.hpp"
+#include "duckdb/function/compression_function.hpp"
+#include "duckdb/transaction/transaction_data.hpp"
 
 namespace duckdb {
 class ColumnSegment;
 class DataTable;
+class LocalTableStorage;
 class RowGroup;
 class UpdateSegment;
-class ValiditySegment;
 
 struct TableAppendState;
 
@@ -29,6 +31,8 @@ struct ColumnAppendState {
 	vector<ColumnAppendState> child_appends;
 	//! The write lock that is held by the append
 	unique_ptr<StorageLockKey> lock;
+	//! The compression append state
+	unique_ptr<CompressionAppendState> append_state;
 };
 
 struct RowGroupAppendState {
@@ -50,14 +54,26 @@ struct IndexLock {
 };
 
 struct TableAppendState {
-	TableAppendState() : row_group_append_state(*this) {
-	}
+	TableAppendState();
+	~TableAppendState();
 
 	RowGroupAppendState row_group_append_state;
 	unique_lock<mutex> append_lock;
 	row_t row_start;
 	row_t current_row;
-	idx_t remaining_append_count;
+	//! The total number of rows appended by the append operation
+	idx_t total_append_count;
+	//! The first row-group that has been appended to
+	RowGroup *start_row_group;
+	//! The transaction data
+	TransactionData transaction;
+	//! The remaining append count, only if the append count is known beforehand
+	idx_t remaining;
+};
+
+struct LocalAppendState {
+	TableAppendState append_state;
+	LocalTableStorage *storage;
 };
 
 } // namespace duckdb
