@@ -1,5 +1,5 @@
 #include "duckdb/main/db_instance_cache.hpp"
-
+#include "duckdb/main/extension_helper.hpp"
 namespace duckdb {
 
 string GetDBAbsolutePath(const string &database) {
@@ -10,6 +10,10 @@ string GetDBAbsolutePath(const string &database) {
 		// this is a memory db, just return it.
 		return database;
 	}
+	if (!ExtensionHelper::ExtractExtensionPrefixFromPath(database).empty()) {
+		// this database path is handled by a replacement open and is not a file path
+		return database;
+	}
 	if (FileSystem::IsPathAbsolute(database)) {
 		return database;
 	}
@@ -23,9 +27,9 @@ shared_ptr<DuckDB> DBInstanceCache::GetInstanceInternal(const string &database,
 		db_instance = db_instances[abs_database_path].lock();
 		if (db_instance) {
 			if (db_instance->instance->config != config) {
-				throw duckdb::Exception(ExceptionType::CONNECTION,
-				                        "Can't open a connection to same database file with a different configuration "
-				                        "than existing connections");
+				throw duckdb::ConnectionException(
+				    "Can't open a connection to same database file with a different configuration "
+				    "than existing connections");
 			}
 		} else {
 			// clean-up
