@@ -8,8 +8,8 @@
 namespace duckdb {
 
 InsertRelation::InsertRelation(shared_ptr<Relation> child_p, string schema_name, string table_name)
-    : Relation(child_p->context, RelationType::INSERT_RELATION), child(move(child_p)), schema_name(move(schema_name)),
-      table_name(move(table_name)) {
+    : Relation(child_p->context, RelationType::INSERT_RELATION), child(std::move(child_p)),
+      schema_name(std::move(schema_name)), table_name(std::move(table_name)) {
 	context.GetContext()->TryBindRelation(*this, this->columns);
 }
 
@@ -20,7 +20,7 @@ BoundStatement InsertRelation::Bind(Binder &binder) {
 
 	stmt.schema = schema_name;
 	stmt.table = table_name;
-	stmt.select_statement = move(select);
+	stmt.select_statement = std::move(select);
 	return binder.Bind((SQLStatement &)stmt);
 }
 
