@@ -12,21 +12,32 @@
 
 namespace duckdb {
 
+void TableFunctionRelation::AddNamedParameter(const string &name, Value argument) {
+	named_parameters[name] = std::move(argument);
+}
+
 TableFunctionRelation::TableFunctionRelation(const std::shared_ptr<ClientContext> &context, string name_p,
                                              vector<Value> parameters_p, named_parameter_map_t named_parameters,
-                                             shared_ptr<Relation> input_relation_p)
+                                             shared_ptr<Relation> input_relation_p, bool auto_init)
     : Relation(context, RelationType::TABLE_FUNCTION_RELATION), name(std::move(name_p)),
       parameters(std::move(parameters_p)), named_parameters(std::move(named_parameters)),
-      input_relation(std::move(input_relation_p)) {
-	context->TryBindRelation(*this, this->columns);
+      input_relation(std::move(input_relation_p)), auto_initialize(auto_init) {
+	InitializeColumns();
 }
-TableFunctionRelation::TableFunctionRelation(const std::shared_ptr<ClientContext> &context, string name_p,
-                                             vector<Value> parameters_p,
 
-                                             shared_ptr<Relation> input_relation_p)
+TableFunctionRelation::TableFunctionRelation(const std::shared_ptr<ClientContext> &context, string name_p,
+                                             vector<Value> parameters_p, shared_ptr<Relation> input_relation_p,
+                                             bool auto_init)
     : Relation(context, RelationType::TABLE_FUNCTION_RELATION), name(std::move(name_p)),
-      parameters(std::move(parameters_p)), input_relation(std::move(input_relation_p)) {
-	context->TryBindRelation(*this, this->columns);
+      parameters(std::move(parameters_p)), input_relation(std::move(input_relation_p)), auto_initialize(auto_init) {
+	InitializeColumns();
+}
+
+void TableFunctionRelation::InitializeColumns() {
+	if (!auto_initialize) {
+		return;
+	}
+	context.GetContext()->TryBindRelation(*this, this->columns);
 }
 
 unique_ptr<QueryNode> TableFunctionRelation::GetQueryNode() {
