@@ -8,7 +8,8 @@
 namespace duckdb {
 
 ViewRelation::ViewRelation(const std::shared_ptr<ClientContext> &context, string schema_name_p, string view_name_p)
-    : Relation(context, RelationType::VIEW_RELATION), schema_name(move(schema_name_p)), view_name(move(view_name_p)) {
+    : Relation(context, RelationType::VIEW_RELATION), schema_name(std::move(schema_name_p)),
+      view_name(std::move(view_name_p)) {
 	context->TryBindRelation(*this, this->columns);
 }
 
@@ -16,14 +17,14 @@ unique_ptr<QueryNode> ViewRelation::GetQueryNode() {
 	auto result = make_unique<SelectNode>();
 	result->select_list.push_back(make_unique<StarExpression>());
 	result->from_table = GetTableRef();
-	return move(result);
+	return std::move(result);
 }
 
 unique_ptr<TableRef> ViewRelation::GetTableRef() {
 	auto table_ref = make_unique<BaseTableRef>();
 	table_ref->schema_name = schema_name;
 	table_ref->table_name = view_name;
-	return move(table_ref);
+	return std::move(table_ref);
 }
 
 string ViewRelation::GetAlias() {
