@@ -12,12 +12,12 @@ unique_ptr<LogicalOperator> FilterPullup::PullupFromLeft(unique_ptr<LogicalOpera
 	FilterPullup left_pullup(true, can_add_column);
 	FilterPullup right_pullup(false, can_add_column);
 
-	op->children[0] = left_pullup.Rewrite(move(op->children[0]));
-	op->children[1] = right_pullup.Rewrite(move(op->children[1]));
+	op->children[0] = left_pullup.Rewrite(std::move(op->children[0]));
+	op->children[1] = right_pullup.Rewrite(std::move(op->children[1]));
 
 	// check only for filters from the LHS
 	if (!left_pullup.filters_expr_pullup.empty() && right_pullup.filters_expr_pullup.empty()) {
-		return GeneratePullupFilter(move(op), left_pullup.filters_expr_pullup);
+		return GeneratePullupFilter(std::move(op), left_pullup.filters_expr_pullup);
 	}
 	return op;
 }
