@@ -40,6 +40,8 @@ unique_ptr<NodeStatistics> StatisticsPropagator::PropagateStatistics(LogicalOper
 	case LogicalOperatorType::LOGICAL_JOIN:
 	case LogicalOperatorType::LOGICAL_DELIM_JOIN:
 		return PropagateStatistics((LogicalJoin &)node, node_ptr);
+	case LogicalOperatorType::LOGICAL_POSITIONAL_JOIN:
+		return PropagateStatistics((LogicalPositionalJoin &)node, node_ptr);
 	case LogicalOperatorType::LOGICAL_UNION:
 	case LogicalOperatorType::LOGICAL_EXCEPT:
 	case LogicalOperatorType::LOGICAL_INTERSECT:
