@@ -12,15 +12,15 @@ ConjunctionExpression::ConjunctionExpression(ExpressionType type)
 ConjunctionExpression::ConjunctionExpression(ExpressionType type, vector<unique_ptr<ParsedExpression>> children)
     : ParsedExpression(type, ExpressionClass::CONJUNCTION) {
 	for (auto &child : children) {
-		AddExpression(move(child));
+		AddExpression(std::move(child));
 	}
 }
 
 ConjunctionExpression::ConjunctionExpression(ExpressionType type, unique_ptr<ParsedExpression> left,
                                              unique_ptr<ParsedExpression> right)
     : ParsedExpression(type, ExpressionClass::CONJUNCTION) {
-	AddExpression(move(left));
-	AddExpression(move(right));
+	AddExpression(std::move(left));
+	AddExpression(std::move(right));
 }
 
 void ConjunctionExpression::AddExpression(unique_ptr<ParsedExpression> expr) {
@@ -28,10 +28,10 @@ void ConjunctionExpression::AddExpression(unique_ptr<ParsedExpression> expr) {
 		// expr is a conjunction of the same type: merge the expression lists together
 		auto &other = (ConjunctionExpression &)*expr;
 		for (auto &child : other.children) {
-			children.push_back(move(child));
+			children.push_back(std::move(child));
 		}
 	} else {
-		children.push_back(move(expr));
+		children.push_back(std::move(expr));
 	}
 }
 
@@ -39,7 +39,7 @@ string ConjunctionExpression::ToString() const {
 	return ToString<ConjunctionExpression, ParsedExpression>(*this);
 }
 
-bool ConjunctionExpression::Equals(const ConjunctionExpression *a, const ConjunctionExpression *b) {
+bool ConjunctionExpression::Equal(const ConjunctionExpression *a, const ConjunctionExpression *b) {
 	return ExpressionUtil::SetEquals(a->children, b->children);
 }
 
@@ -48,9 +48,9 @@ unique_ptr<ParsedExpression> ConjunctionExpression::Copy() const {
 	for (auto &expr : children) {
 		copy_children.push_back(expr->Copy());
 	}
-	auto copy = make_unique<ConjunctionExpression>(type, move(copy_children));
+	auto copy = make_unique<ConjunctionExpression>(type, std::move(copy_children));
 	copy->CopyProperties(*this);
-	return move(copy);
+	return std::move(copy);
 }
 
 void ConjunctionExpression::Serialize(FieldWriter &writer) const {
@@ -60,7 +60,7 @@ void ConjunctionExpression::Serialize(FieldWriter &writer) const {
 unique_ptr<ParsedExpression> ConjunctionExpression::Deserialize(ExpressionType type, FieldReader &reader) {
 	auto result = make_unique<ConjunctionExpression>(type);
 	result->children = reader.ReadRequiredSerializableList<ParsedExpression>();
-	return move(result);
+	return std::move(result);
 }
 
 } // namespace duckdb
