@@ -8,14 +8,14 @@
 namespace duckdb {
 
 ConstantExpression::ConstantExpression(Value val)
-    : ParsedExpression(ExpressionType::VALUE_CONSTANT, ExpressionClass::CONSTANT), value(move(val)) {
+    : ParsedExpression(ExpressionType::VALUE_CONSTANT, ExpressionClass::CONSTANT), value(std::move(val)) {
 }
 
 string ConstantExpression::ToString() const {
 	return value.ToSQLString();
 }
 
-bool ConstantExpression::Equals(const ConstantExpression *a, const ConstantExpression *b) {
+bool ConstantExpression::Equal(const ConstantExpression *a, const ConstantExpression *b) {
 	return a->value.type() == b->value.type() && !ValueOperations::DistinctFrom(a->value, b->value);
 }
 
@@ -26,7 +26,7 @@ hash_t ConstantExpression::Hash() const {
 unique_ptr<ParsedExpression> ConstantExpression::Copy() const {
 	auto copy = make_unique<ConstantExpression>(value);
 	copy->CopyProperties(*this);
-	return move(copy);
+	return std::move(copy);
 }
 
 void ConstantExpression::Serialize(FieldWriter &writer) const {
@@ -35,7 +35,7 @@ void ConstantExpression::Serialize(FieldWriter &writer) const {
 
 unique_ptr<ParsedExpression> ConstantExpression::Deserialize(ExpressionType type, FieldReader &reader) {
 	Value value = reader.ReadRequiredSerializable<Value, Value>();
-	return make_unique<ConstantExpression>(move(value));
+	return make_unique<ConstantExpression>(std::move(value));
 }
 
 } // namespace duckdb
