@@ -6,8 +6,9 @@
 
 namespace duckdb {
 
-AlterInfo::AlterInfo(AlterType type, string schema_p, string name_p, bool if_exists)
-    : type(type), if_exists(if_exists), schema(move(schema_p)), name(move(name_p)) {
+AlterInfo::AlterInfo(AlterType type, string catalog_p, string schema_p, string name_p, bool if_exists)
+    : type(type), if_exists(if_exists), catalog(std::move(catalog_p)), schema(std::move(schema_p)),
+      name(std::move(name_p)), allow_internal(false) {
 }
 
 AlterInfo::~AlterInfo() {
@@ -43,4 +44,13 @@ unique_ptr<AlterInfo> AlterInfo::Deserialize(Deserializer &source) {
 	return result;
 }
 
+AlterEntryData AlterInfo::GetAlterEntryData() const {
+	AlterEntryData data;
+	data.catalog = catalog;
+	data.schema = schema;
+	data.name = name;
+	data.if_exists = if_exists;
+	return data;
+}
+
 } // namespace duckdb
