@@ -3,7 +3,8 @@
 namespace duckdb {
 
 ExtensionStatement::ExtensionStatement(ParserExtension extension_p, unique_ptr<ParserExtensionParseData> parse_data_p)
-    : SQLStatement(StatementType::EXTENSION_STATEMENT), extension(move(extension_p)), parse_data(move(parse_data_p)) {
+    : SQLStatement(StatementType::EXTENSION_STATEMENT), extension(std::move(extension_p)),
+      parse_data(std::move(parse_data_p)) {
 }
 
 unique_ptr<SQLStatement> ExtensionStatement::Copy() const {
