@@ -11,8 +11,8 @@ string SubqueryRef::ToString() const {
 }
 
 SubqueryRef::SubqueryRef(unique_ptr<SelectStatement> subquery_p, string alias_p)
-    : TableRef(TableReferenceType::SUBQUERY), subquery(move(subquery_p)) {
-	this->alias = move(alias_p);
+    : TableRef(TableReferenceType::SUBQUERY), subquery(std::move(subquery_p)) {
+	this->alias = std::move(alias_p);
 }
 
 bool SubqueryRef::Equals(const TableRef *other_p) const {
@@ -27,7 +27,7 @@ unique_ptr<TableRef> SubqueryRef::Copy() {
 	auto copy = make_unique<SubqueryRef>(unique_ptr_cast<SQLStatement, SelectStatement>(subquery->Copy()), alias);
 	copy->column_name_alias = column_name_alias;
 	CopyProperties(*copy);
-	return move(copy);
+	return std::move(copy);
 }
 
 void SubqueryRef::Serialize(FieldWriter &writer) const {
@@ -37,9 +37,9 @@ void SubqueryRef::Serialize(FieldWriter &writer) const {
 
 unique_ptr<TableRef> SubqueryRef::Deserialize(FieldReader &reader) {
 	auto subquery = reader.ReadRequiredSerializable<SelectStatement>();
-	auto result = make_unique<SubqueryRef>(move(subquery));
+	auto result = make_unique<SubqueryRef>(std::move(subquery));
 	result->column_name_alias = reader.ReadRequiredList<string>();
-	return move(result);
+	return std::move(result);
 }
 
 } // namespace duckdb
