@@ -812,6 +812,12 @@ std::string Transformer::NodetypeToString(duckdb_libpgquery::PGNodeTag type) { /
 		return "T_TsmRoutine";
 	case duckdb_libpgquery::T_PGForeignKeyCacheInfo:
 		return "T_ForeignKeyCacheInfo";
+	case duckdb_libpgquery::T_PGAttachStmt:
+		return "T_PGAttachStmt";
+	case duckdb_libpgquery::T_PGUseStmt:
+		return "T_PGUseStmt";
+	case duckdb_libpgquery::T_PGCreateDatabaseStmt:
+		return "T_PGCreateDatabaseStmt";
 	default:
 		return "(UNKNOWN)";
 	}
