@@ -2,15 +2,14 @@
 
 namespace duckdb {
 
-using namespace duckdb_libpgquery;
-
-string Transformer::TransformAlias(PGAlias *root, vector<string> &column_name_alias) {
+string Transformer::TransformAlias(duckdb_libpgquery::PGAlias *root, vector<string> &column_name_alias) {
 	if (!root) {
 		return "";
 	}
 	if (root->colnames) {
 		for (auto node = root->colnames->head; node != nullptr; node = node->next) {
-			column_name_alias.push_back(reinterpret_cast<PGValue *>(node->data.ptr_value)->val.str);
+			column_name_alias.emplace_back(
+			    reinterpret_cast<duckdb_libpgquery::PGValue *>(node->data.ptr_value)->val.str);
 		}
 	}
 	return root->aliasname;
