@@ -14,6 +14,7 @@ unique_ptr<CreateStatement> Transformer::TransformCreateSequence(duckdb_libpgque
 	auto info = make_unique<CreateSequenceInfo>();
 
 	auto qname = TransformQualifiedName(stmt->sequence);
+	info->catalog = qname.catalog;
 	info->schema = qname.schema;
 	info->name = qname.name;
 
@@ -122,7 +123,7 @@ unique_ptr<CreateStatement> Transformer::TransformCreateSequence(duckdb_libpgque
 		throw ParserException("START value (%lld) cannot be greater than MAXVALUE (%lld)", info->start_value,
 		                      info->max_value);
 	}
-	result->info = move(info);
+	result->info = std::move(info);
 	return result;
 }
 
