@@ -36,34 +36,52 @@ unique_ptr<SQLStatement> Transformer::TransformDrop(duckdb_libpgquery::PGNode *n
 	case duckdb_libpgquery::PG_OBJECT_TYPE:
 		info.type = CatalogType::TYPE_ENTRY;
 		break;
+	case duckdb_libpgquery::PG_OBJECT_DATABASE:
+		info.type = CatalogType::DATABASE_ENTRY;
+		break;
 	default:
 		throw NotImplementedException("Cannot drop this type yet");
 	}
 
 	switch (stmt->removeType) {
-	case duckdb_libpgquery::PG_OBJECT_SCHEMA:
-		info.name = ((duckdb_libpgquery::PGValue *)stmt->objects->head->data.ptr_value)->val.str;
-		break;
 	case duckdb_libpgquery::PG_OBJECT_TYPE: {
 		auto view_list = (duckdb_libpgquery::PGList *)stmt->objects;
 		auto target = (duckdb_libpgquery::PGTypeName *)(view_list->head->data.ptr_value);
 		info.name = (reinterpret_cast<duckdb_libpgquery::PGValue *>(target->names->tail->data.ptr_value)->val.str);
 		break;
 	}
-	default: {
+	case duckdb_libpgquery::PG_OBJECT_SCHEMA: {
 		auto view_list = (duckdb_libpgquery::PGList *)stmt->objects->head->data.ptr_value;
 		if (view_list->length == 2) {
+			info.catalog = ((duckdb_libpgquery::PGValue *)view_list->head->data.ptr_value)->val.str;
+			info.name = ((duckdb_libpgquery::PGValue *)view_list->head->next->data.ptr_value)->val.str;
+		} else if (view_list->length == 1) {
+			info.name = ((duckdb_libpgquery::PGValue *)view_list->head->data.ptr_value)->val.str;
+		} else {
+			throw ParserException("Expected \"catalog.schema\" or \"schema\"");
+		}
+		break;
+	}
+	default: {
+		auto view_list = (duckdb_libpgquery::PGList *)stmt->objects->head->data.ptr_value;
+		if (view_list->length == 3) {
+			info.catalog = ((duckdb_libpgquery::PGValue *)view_list->head->data.ptr_value)->val.str;
+			info.schema = ((duckdb_libpgquery::PGValue *)view_list->head->next->data.ptr_value)->val.str;
+			info.name = ((duckdb_libpgquery::PGValue *)view_list->head->next->next->data.ptr_value)->val.str;
+		} else if (view_list->length == 2) {
 			info.schema = ((duckdb_libpgquery::PGValue *)view_list->head->data.ptr_value)->val.str;
 			info.name = ((duckdb_libpgquery::PGValue *)view_list->head->next->data.ptr_value)->val.str;
-		} else {
+		} else if (view_list->length == 1) {
 			info.name = ((duckdb_libpgquery::PGValue *)view_list->head->data.ptr_value)->val.str;
+		} else {
+			throw ParserException("Expected \"catalog.schema.name\", \"schema.name\"or \"name\"");
 		}
 		break;
 	}
 	}
 	info.cascade = stmt->behavior == duckdb_libpgquery::PGDropBehavior::PG_DROP_CASCADE;
 	info.if_exists = stmt->missing_ok;
-	return move(result);
+	return std::move(result);
 }
 
 } // namespace duckdb
