@@ -25,10 +25,10 @@ unique_ptr<TableRef> Transformer::TransformValuesList(duckdb_libpgquery::PGList
 unique_ptr<InsertStatement> Transformer::TransformInsert(duckdb_libpgquery::PGNode *node) {
 	auto stmt = reinterpret_cast<duckdb_libpgquery::PGInsertStmt *>(node);
 	D_ASSERT(stmt);
-	if (stmt->onConflictClause && stmt->onConflictClause->action != duckdb_libpgquery::PG_ONCONFLICT_NONE) {
-		throw ParserException("ON CONFLICT IGNORE/UPDATE clauses are not supported");
-	}
+
 	if (!stmt->selectStmt) {
+		// TODO: This should be easy to add, we already support DEFAULT in the values list,
+		// this could probably just be transformed into VALUES (DEFAULT, DEFAULT, DEFAULT, ..) in the Binder
 		throw ParserException("DEFAULT VALUES clause is not supported!");
 	}
 
@@ -54,6 +54,21 @@ unique_ptr<InsertStatement> Transformer::TransformInsert(duckdb_libpgquery::PGNo
 	auto qname = TransformQualifiedName(stmt->relation);
 	result->table = qname.name;
 	result->schema = qname.schema;
+
+	if (stmt->onConflictClause) {
+		if (stmt->onConflictAlias != duckdb_libpgquery::PG_ONCONFLICT_ALIAS_NONE) {
+			// OR REPLACE | OR IGNORE are shorthands for the ON CONFLICT clause
+			throw ParserException("You can not provide both OR REPLACE|IGNORE and an ON CONFLICT clause, please remove "
+			                      "the first if you want to have more granual control");
+		}
+		result->on_conflict_info = TransformOnConflictClause(stmt->onConflictClause, result->schema);
+		result->table_ref = TransformRangeVar(stmt->relation);
+	}
+	if (stmt->onConflictAlias != duckdb_libpgquery::PG_ONCONFLICT_ALIAS_NONE) {
+		D_ASSERT(!stmt->onConflictClause);
+		result->on_conflict_info = DummyOnConflictClause(stmt->onConflictAlias, result->schema);
+		result->table_ref = TransformRangeVar(stmt->relation);
+	}
 	result->catalog = qname.catalog;
 	return result;
 }
