@@ -16,6 +16,9 @@ unique_ptr<PrepareStatement> Transformer::TransformPrepare(duckdb_libpgquery::PG
 	auto result = make_unique<PrepareStatement>();
 	result->name = string(stmt->name);
 	result->statement = TransformStatement(stmt->query);
+	if (!result->statement->named_param_map.empty()) {
+		throw NotImplementedException("Named parameters are not supported in this client yet");
+	}
 	SetParamCount(0);
 
 	return result;
