@@ -1,4 +1,4 @@
-#include "duckdb/parser/tableref/crossproductref.hpp"
+#include "duckdb/parser/tableref/joinref.hpp"
 #include "duckdb/parser/tableref/emptytableref.hpp"
 #include "duckdb/parser/transformer.hpp"
 
@@ -11,8 +11,8 @@ unique_ptr<TableRef> Transformer::TransformFrom(duckdb_libpgquery::PGList *root)
 
 	if (root->length > 1) {
 		// Cross Product
-		auto result = make_unique<CrossProductRef>();
-		CrossProductRef *cur_root = result.get();
+		auto result = make_unique<JoinRef>(JoinRefType::CROSS);
+		JoinRef *cur_root = result.get();
 		idx_t list_size = 0;
 		for (auto node = root->head; node != nullptr; node = node->next) {
 			auto n = reinterpret_cast<duckdb_libpgquery::PGNode *>(node->data.ptr_value);
@@ -23,7 +23,7 @@ unique_ptr<TableRef> Transformer::TransformFrom(duckdb_libpgquery::PGList *root)
 				cur_root->right = std::move(next);
 			} else {
 				auto old_res = std::move(result);
-				result = make_unique<CrossProductRef>();
+				result = make_unique<JoinRef>(JoinRefType::CROSS);
 				result->left = std::move(old_res);
 				result->right = std::move(next);
 				cur_root = result.get();
