@@ -20,10 +20,11 @@ BindResult ExpressionBinder::BindExpression(ConjunctionExpression &expr, idx_t d
 	auto result = make_unique<BoundConjunctionExpression>(expr.type);
 	for (auto &child_expr : expr.children) {
 		auto &child = (BoundExpression &)*child_expr;
-		result->children.push_back(BoundCastExpression::AddCastToType(context, move(child.expr), LogicalType::BOOLEAN));
+		result->children.push_back(
+		    BoundCastExpression::AddCastToType(context, std::move(child.expr), LogicalType::BOOLEAN));
 	}
 	// now create the bound conjunction expression
-	return BindResult(move(result));
+	return BindResult(std::move(result));
 }
 
 } // namespace duckdb
