@@ -1,9 +1,13 @@
 #include "duckdb/parser/statement/drop_statement.hpp"
 #include "duckdb/planner/binder.hpp"
+#include "duckdb/planner/bound_tableref.hpp"
 #include "duckdb/planner/operator/logical_simple.hpp"
 #include "duckdb/catalog/catalog.hpp"
 #include "duckdb/catalog/standard_entry.hpp"
 #include "duckdb/catalog/catalog_entry/schema_catalog_entry.hpp"
+#include "duckdb/parser/parsed_data/drop_info.hpp"
+#include "duckdb/main/config.hpp"
+#include "duckdb/storage/storage_extension.hpp"
 
 namespace duckdb {
 
@@ -43,10 +47,31 @@ BoundStatement Binder::Bind(DropStatement &stmt) {
 		stmt.info->schema = entry->schema->name;
 		break;
 	}
-	case CatalogType::DATABASE_ENTRY:
-		// attaching and detaching is read-only
-		stmt.info->catalog = SYSTEM_CATALOG;
-		break;
+	case CatalogType::DATABASE_ENTRY: {
+		auto &base = (DropInfo &)*stmt.info;
+		string database_name = base.name;
+
+		auto &config = DBConfig::GetConfig(context);
+		// for now assume only one storage extension provides the custom drop_database impl
+		for (auto &extension_entry : config.storage_extensions) {
+			if (extension_entry.second->drop_database == nullptr) {
+				continue;
+			}
+			auto &storage_extension = extension_entry.second;
+			auto drop_database_function_ref =
+			    storage_extension->drop_database(storage_extension->storage_info.get(), context, database_name);
+			if (drop_database_function_ref) {
+				auto bound_drop_database_func = Bind(*drop_database_function_ref);
+				result.plan = CreatePlan(*bound_drop_database_func);
+				result.names = {"Success"};
+				result.types = {LogicalType::BIGINT};
+				properties.allow_stream_result = false;
+				properties.return_type = StatementReturnType::NOTHING;
+				return result;
+			}
+		}
+		throw BinderException("Drop is not supported for this database!");
+	}
 	default:
 		throw BinderException("Unknown catalog type for drop statement!");
 	}
