@@ -1,6 +1,7 @@
 #include "duckdb/parser/expression/columnref_expression.hpp"
 #include "duckdb/parser/statement/update_statement.hpp"
 #include "duckdb/planner/binder.hpp"
+#include "duckdb/planner/tableref/bound_joinref.hpp"
 #include "duckdb/planner/bound_tableref.hpp"
 #include "duckdb/planner/constraints/bound_check_constraint.hpp"
 #include "duckdb/planner/expression/bound_columnref_expression.hpp"
@@ -12,7 +13,7 @@
 #include "duckdb/planner/operator/logical_projection.hpp"
 #include "duckdb/planner/operator/logical_update.hpp"
 #include "duckdb/planner/tableref/bound_basetableref.hpp"
-#include "duckdb/planner/tableref/bound_crossproductref.hpp"
+#include "duckdb/catalog/catalog_entry/duck_table_entry.hpp"
 #include "duckdb/storage/data_table.hpp"
 
 #include <algorithm>
@@ -42,7 +43,7 @@ static void BindExtraColumns(TableCatalogEntry &table, LogicalGet &get, LogicalP
 				continue;
 			}
 			// column is not projected yet: project it by adding the clause "i=i" to the set of updated columns
-			auto &column = table.columns.GetColumn(check_column_id);
+			auto &column = table.GetColumns().GetColumn(check_column_id);
 			update.expressions.push_back(make_unique<BoundColumnRefExpression>(
 			    column.Type(), ColumnBinding(proj.table_index, proj.expressions.size())));
 			proj.expressions.push_back(make_unique<BoundColumnRefExpression>(
@@ -76,21 +77,25 @@ static bool TypeSupportsRegularUpdate(const LogicalType &type) {
 
 static void BindUpdateConstraints(TableCatalogEntry &table, LogicalGet &get, LogicalProjection &proj,
                                   LogicalUpdate &update) {
+	if (!table.IsDuckTable()) {
+		return;
+	}
 	// check the constraints and indexes of the table to see if we need to project any additional columns
 	// we do this for indexes with multiple columns and CHECK constraints in the UPDATE clause
 	// suppose we have a constraint CHECK(i + j < 10); now we need both i and j to check the constraint
 	// if we are only updating one of the two columns we add the other one to the UPDATE set
 	// with a "useless" update (i.e. i=i) so we can verify that the CHECK constraint is not violated
-	for (auto &constraint : table.bound_constraints) {
+	for (auto &constraint : table.GetBoundConstraints()) {
 		if (constraint->type == ConstraintType::CHECK) {
 			auto &check = *reinterpret_cast<BoundCheckConstraint *>(constraint.get());
 			// check constraint! check if we need to add any extra columns to the UPDATE clause
 			BindExtraColumns(table, get, proj, update, check.bound_columns);
 		}
 	}
+	auto &storage = table.GetStorage();
 	if (update.return_chunk) {
 		physical_index_set_t all_columns;
-		for (idx_t i = 0; i < table.storage->column_definitions.size(); i++) {
+		for (idx_t i = 0; i < storage.column_definitions.size(); i++) {
 			all_columns.insert(PhysicalIndex(i));
 		}
 		BindExtraColumns(table, get, proj, update, all_columns);
@@ -100,7 +105,7 @@ static void BindUpdateConstraints(TableCatalogEntry &table, LogicalGet &get, Log
 	// If the returning keyword is used, we need access to the whole row in case the user requests it.
 	// Therefore switch the update to a delete and insert.
 	update.update_is_del_and_insert = false;
-	table.storage->info->indexes.Scan([&](Index &index) {
+	storage.info->indexes.Scan([&](Index &index) {
 		if (index.IndexIsUpdated(update.columns)) {
 			update.update_is_del_and_insert = true;
 			return true;
@@ -110,7 +115,7 @@ static void BindUpdateConstraints(TableCatalogEntry &table, LogicalGet &get, Log
 
 	// we also convert any updates on LIST columns into delete + insert
 	for (auto &col_index : update.columns) {
-		auto &column = table.columns.GetColumn(col_index);
+		auto &column = table.GetColumns().GetColumn(col_index);
 		if (!TypeSupportsRegularUpdate(column.Type())) {
 			update.update_is_del_and_insert = true;
 			break;
@@ -121,13 +126,58 @@ static void BindUpdateConstraints(TableCatalogEntry &table, LogicalGet &get, Log
 		// the update updates a column required by an index or requires returning the updated rows,
 		// push projections for all columns
 		physical_index_set_t all_columns;
-		for (idx_t i = 0; i < table.storage->column_definitions.size(); i++) {
+		for (idx_t i = 0; i < storage.column_definitions.size(); i++) {
 			all_columns.insert(PhysicalIndex(i));
 		}
 		BindExtraColumns(table, get, proj, update, all_columns);
 	}
 }
 
+// This creates a LogicalProjection and moves 'root' into it as a child
+// unless there are no expressions to project, in which case it just returns 'root'
+unique_ptr<LogicalOperator> Binder::BindUpdateSet(LogicalOperator *op, unique_ptr<LogicalOperator> root,
+                                                  UpdateSetInfo &set_info, TableCatalogEntry *table,
+                                                  vector<PhysicalIndex> &columns) {
+	auto proj_index = GenerateTableIndex();
+
+	vector<unique_ptr<Expression>> projection_expressions;
+	D_ASSERT(set_info.columns.size() == set_info.expressions.size());
+	for (idx_t i = 0; i < set_info.columns.size(); i++) {
+		auto &colname = set_info.columns[i];
+		auto &expr = set_info.expressions[i];
+		if (!table->ColumnExists(colname)) {
+			throw BinderException("Referenced update column %s not found in table!", colname);
+		}
+		auto &column = table->GetColumn(colname);
+		if (column.Generated()) {
+			throw BinderException("Cant update column \"%s\" because it is a generated column!", column.Name());
+		}
+		if (std::find(columns.begin(), columns.end(), column.Physical()) != columns.end()) {
+			throw BinderException("Multiple assignments to same column \"%s\"", colname);
+		}
+		columns.push_back(column.Physical());
+		if (expr->type == ExpressionType::VALUE_DEFAULT) {
+			op->expressions.push_back(make_unique<BoundDefaultExpression>(column.Type()));
+		} else {
+			UpdateBinder binder(*this, context);
+			binder.target_type = column.Type();
+			auto bound_expr = binder.Bind(expr);
+			PlanSubqueries(&bound_expr, &root);
+
+			op->expressions.push_back(make_unique<BoundColumnRefExpression>(
+			    bound_expr->return_type, ColumnBinding(proj_index, projection_expressions.size())));
+			projection_expressions.push_back(std::move(bound_expr));
+		}
+	}
+	if (op->type != LogicalOperatorType::LOGICAL_UPDATE && projection_expressions.empty()) {
+		return root;
+	}
+	// now create the projection
+	auto proj = make_unique<LogicalProjection>(proj_index, std::move(projection_expressions));
+	proj->AddChild(std::move(root));
+	return unique_ptr_cast<LogicalProjection, LogicalOperator>(std::move(proj));
+}
+
 BoundStatement Binder::Bind(UpdateStatement &stmt) {
 	BoundStatement result;
 	unique_ptr<LogicalOperator> root;
@@ -145,7 +195,7 @@ BoundStatement Binder::Bind(UpdateStatement &stmt) {
 	AddCTEMap(stmt.cte_map);
 
 	if (stmt.from_table) {
-		BoundCrossProductRef bound_crossproduct;
+		BoundJoinRef bound_crossproduct(JoinRefType::CROSS);
 		bound_crossproduct.left = std::move(bound_table);
 		bound_crossproduct.right = Bind(*stmt.from_table);
 		root = CreatePlan(bound_crossproduct);
@@ -166,12 +216,12 @@ BoundStatement Binder::Bind(UpdateStatement &stmt) {
 		update->return_chunk = true;
 	}
 	// bind the default values
-	BindDefaultValues(table->columns, update->bound_defaults);
+	BindDefaultValues(table->GetColumns(), update->bound_defaults);
 
 	// project any additional columns required for the condition/expressions
-	if (stmt.condition) {
+	if (stmt.set_info->condition) {
 		WhereBinder binder(*this, context);
-		auto condition = binder.Bind(stmt.condition);
+		auto condition = binder.Bind(stmt.set_info->condition);
 
 		PlanSubqueries(&condition, &root);
 		auto filter = make_unique<LogicalFilter>(std::move(condition));
@@ -179,47 +229,15 @@ BoundStatement Binder::Bind(UpdateStatement &stmt) {
 		root = std::move(filter);
 	}
 
-	D_ASSERT(stmt.columns.size() == stmt.expressions.size());
+	D_ASSERT(stmt.set_info);
+	D_ASSERT(stmt.set_info->columns.size() == stmt.set_info->expressions.size());
 
-	auto proj_index = GenerateTableIndex();
-	vector<unique_ptr<Expression>> projection_expressions;
-
-	for (idx_t i = 0; i < stmt.columns.size(); i++) {
-		auto &colname = stmt.columns[i];
-		auto &expr = stmt.expressions[i];
-		if (!table->ColumnExists(colname)) {
-			throw BinderException("Referenced update column %s not found in table!", colname);
-		}
-		auto &column = table->GetColumn(colname);
-		if (column.Generated()) {
-			throw BinderException("Cant update column \"%s\" because it is a generated column!", column.Name());
-		}
-		if (std::find(update->columns.begin(), update->columns.end(), column.Physical()) != update->columns.end()) {
-			throw BinderException("Multiple assignments to same column \"%s\"", colname);
-		}
-		update->columns.push_back(column.Physical());
-
-		if (expr->type == ExpressionType::VALUE_DEFAULT) {
-			update->expressions.push_back(make_unique<BoundDefaultExpression>(column.Type()));
-		} else {
-			UpdateBinder binder(*this, context);
-			binder.target_type = column.Type();
-			auto bound_expr = binder.Bind(expr);
-			PlanSubqueries(&bound_expr, &root);
-
-			update->expressions.push_back(make_unique<BoundColumnRefExpression>(
-			    bound_expr->return_type, ColumnBinding(proj_index, projection_expressions.size())));
-			projection_expressions.push_back(std::move(bound_expr));
-		}
-	}
-
-	// now create the projection
-	auto proj = make_unique<LogicalProjection>(proj_index, std::move(projection_expressions));
-	proj->AddChild(std::move(root));
+	auto proj_tmp = BindUpdateSet(update.get(), std::move(root), *stmt.set_info, table, update->columns);
+	D_ASSERT(proj_tmp->type == LogicalOperatorType::LOGICAL_PROJECTION);
+	auto proj = unique_ptr_cast<LogicalOperator, LogicalProjection>(std::move(proj_tmp));
 
 	// bind any extra columns necessary for CHECK constraints or indexes
 	BindUpdateConstraints(*table, *get, *proj, *update);
-
 	// finally add the row id column to the projection list
 	proj->expressions.push_back(make_unique<BoundColumnRefExpression>(
 	    LogicalType::ROW_TYPE, ColumnBinding(get->table_index, get->column_ids.size())));
