@@ -1,13 +1,26 @@
 #include "duckdb/planner/expression_binder/table_function_binder.hpp"
 #include "duckdb/parser/expression/columnref_expression.hpp"
 #include "duckdb/planner/expression/bound_constant_expression.hpp"
+#include "duckdb/planner/table_binding.hpp"
 
 namespace duckdb {
 
 TableFunctionBinder::TableFunctionBinder(Binder &binder, ClientContext &context) : ExpressionBinder(binder, context) {
 }
 
-BindResult TableFunctionBinder::BindColumnReference(ColumnRefExpression &expr) {
+BindResult TableFunctionBinder::BindColumnReference(ColumnRefExpression &expr, idx_t depth) {
+
+	// if this is a lambda parameters, then we temporarily add a BoundLambdaRef,
+	// which we capture and remove later
+	if (lambda_bindings) {
+		auto &colref = (ColumnRefExpression &)expr;
+		for (idx_t i = 0; i < lambda_bindings->size(); i++) {
+			if (colref.GetColumnName() == (*lambda_bindings)[i].dummy_name) {
+				return (*lambda_bindings)[i].Bind(colref, i, depth);
+			}
+		}
+	}
+
 	auto result_name = StringUtil::Join(expr.column_names, ".");
 	return BindResult(make_unique<BoundConstantExpression>(Value(result_name)));
 }
@@ -17,7 +30,7 @@ BindResult TableFunctionBinder::BindExpression(unique_ptr<ParsedExpression> *exp
 	auto &expr = **expr_ptr;
 	switch (expr.GetExpressionClass()) {
 	case ExpressionClass::COLUMN_REF:
-		return BindColumnReference((ColumnRefExpression &)expr);
+		return BindColumnReference((ColumnRefExpression &)expr, depth);
 	case ExpressionClass::SUBQUERY:
 		throw BinderException("Table function cannot contain subqueries");
 	case ExpressionClass::DEFAULT:
