@@ -9,7 +9,7 @@ void LogicalCreateTable::Serialize(FieldWriter &writer) const {
 unique_ptr<LogicalOperator> LogicalCreateTable::Deserialize(LogicalDeserializationState &state, FieldReader &reader) {
 	auto info = reader.ReadRequiredSerializable<BoundCreateTableInfo>(state.gstate);
 	auto schema = info->schema;
-	return make_unique<LogicalCreateTable>(schema, move(info));
+	return make_unique<LogicalCreateTable>(schema, std::move(info));
 }
 
 idx_t LogicalCreateTable::EstimateCardinality(ClientContext &context) {
