@@ -1,8 +1,14 @@
 #include "duckdb/planner/operator/logical_delete.hpp"
 #include "duckdb/parser/parsed_data/create_table_info.hpp"
+#include "duckdb/catalog/catalog_entry/table_catalog_entry.hpp"
 
 namespace duckdb {
 
+LogicalDelete::LogicalDelete(TableCatalogEntry *table, idx_t table_index)
+    : LogicalOperator(LogicalOperatorType::LOGICAL_DELETE), table(table), table_index(table_index),
+      return_chunk(false) {
+}
+
 void LogicalDelete::Serialize(FieldWriter &writer) const {
 	table->Serialize(writer.GetSerializer());
 	writer.WriteField(table_index);
@@ -30,4 +36,19 @@ vector<idx_t> LogicalDelete::GetTableIndex() const {
 	return vector<idx_t> {table_index};
 }
 
+vector<ColumnBinding> LogicalDelete::GetColumnBindings() {
+	if (return_chunk) {
+		return GenerateColumnBindings(table_index, table->GetTypes().size());
+	}
+	return {ColumnBinding(0, 0)};
+}
+
+void LogicalDelete::ResolveTypes() {
+	if (return_chunk) {
+		types = table->GetTypes();
+	} else {
+		types.emplace_back(LogicalType::BIGINT);
+	}
+}
+
 } // namespace duckdb
