@@ -27,7 +27,7 @@ unique_ptr<LogicalOperator> LogicalWindow::Deserialize(LogicalDeserializationSta
 	auto window_index = reader.ReadRequired<idx_t>();
 	auto result = make_unique<LogicalWindow>(window_index);
 	result->expressions = reader.ReadRequiredSerializableList<Expression>(state.gstate);
-	return move(result);
+	return std::move(result);
 }
 
 vector<idx_t> LogicalWindow::GetTableIndex() const {
