@@ -212,17 +212,11 @@ public:
 		}
 	}
 
-	void CreateEmptySegment(idx_t row_start) {
-		auto &db = checkpointer.GetDatabase();
-		auto &type = checkpointer.GetType();
-		auto compressed_segment = ColumnSegment::CreateTransientSegment(db, type, row_start);
-		current_segment = std::move(compressed_segment);
-
-		current_segment->function = function;
-
-		// Reset the buffers and string map
+	void Reset() {
 		index_buffer.clear();
 		current_width = 0;
+		max_compressed_string_length = 0;
+		last_fitting_size = 0;
 
 		// Reset the pointers into the current segment
 		auto &buffer_manager = BufferManager::GetBufferManager(current_segment->db);
@@ -231,11 +225,21 @@ public:
 		current_end_ptr = current_handle.Ptr() + current_dictionary.end;
 	}
 
-	void UpdateState(string_t uncompressed_string, unsigned char *compressed_string, size_t compressed_string_len) {
+	void CreateEmptySegment(idx_t row_start) {
+		auto &db = checkpointer.GetDatabase();
+		auto &type = checkpointer.GetType();
+		auto compressed_segment = ColumnSegment::CreateTransientSegment(db, type, row_start);
+		current_segment = std::move(compressed_segment);
+		current_segment->function = function;
+		Reset();
+	}
 
+	void UpdateState(string_t uncompressed_string, unsigned char *compressed_string, size_t compressed_string_len) {
 		if (!HasEnoughSpace(compressed_string_len)) {
 			Flush();
-			D_ASSERT(HasEnoughSpace(compressed_string_len));
+			if (!HasEnoughSpace(compressed_string_len)) {
+				throw InternalException("FSST string compression failed due to insufficient space in empty block");
+			};
 		}
 
 		UncompressedStringStorage::UpdateStringStats(current_segment->stats, uncompressed_string);
@@ -258,7 +262,9 @@ public:
 	void AddNull() {
 		if (!HasEnoughSpace(0)) {
 			Flush();
-			D_ASSERT(HasEnoughSpace(0));
+			if (!HasEnoughSpace(0)) {
+				throw InternalException("FSST string compression failed due to insufficient space in empty block");
+			};
 		}
 		index_buffer.push_back(0);
 		current_segment->count++;
@@ -269,7 +275,7 @@ public:
 		UncompressedStringStorage::UpdateStringStats(current_segment->stats, "");
 	}
 
-	bool HasEnoughSpace(size_t string_len) {
+	size_t GetRequiredSize(size_t string_len) {
 		bitpacking_width_t required_minimum_width;
 		if (string_len > max_compressed_string_length) {
 			required_minimum_width = BitpackingPrimitives::MinimumBitWidth(string_len);
@@ -284,10 +290,19 @@ public:
 		    BitpackingPrimitives::GetRequiredSize(current_string_count + 1, required_minimum_width);
 
 		// TODO switch to a symbol table per RowGroup, saves a bit of space
-		idx_t required_space = sizeof(fsst_compression_header_t) + current_dict_size + dict_offsets_size + string_len +
-		                       fsst_serialized_symbol_table_size;
+		return sizeof(fsst_compression_header_t) + current_dict_size + dict_offsets_size + string_len +
+		       fsst_serialized_symbol_table_size;
+	}
 
-		return required_space <= Storage::BLOCK_SIZE;
+	// Checks if there is enough space, if there is, sets last_fitting_size
+	bool HasEnoughSpace(size_t string_len) {
+		auto required_size = GetRequiredSize(string_len);
+
+		if (required_size <= Storage::BLOCK_SIZE) {
+			last_fitting_size = required_size;
+			return true;
+		}
+		return false;
 	}
 
 	void Flush(bool final = false) {
@@ -313,6 +328,10 @@ public:
 		auto total_size = sizeof(fsst_compression_header_t) + compressed_index_buffer_size + current_dictionary.size +
 		                  fsst_serialized_symbol_table_size;
 
+		if (total_size != last_fitting_size) {
+			throw InternalException("FSST string compression failed due to incorrect size calculation");
+		}
+
 		// calculate ptr and offsets
 		auto base_ptr = handle.Ptr();
 		auto header_ptr = (fsst_compression_header_t *)base_ptr;
@@ -334,11 +353,6 @@ public:
 		Store<uint32_t>(symbol_table_offset, (data_ptr_t)&header_ptr->fsst_symbol_table_offset);
 		Store<uint32_t>((uint32_t)current_width, (data_ptr_t)&header_ptr->bitpacking_width);
 
-		if (symbol_table_offset + fsst_serialized_symbol_table_size >
-		    current_dictionary.end - current_dictionary.size) {
-			throw InternalException("FSST string compression failed due to incorrect size calculation");
-		}
-
 		if (total_size >= FSSTStorage::COMPACTION_FLUSH_LIMIT) {
 			// the block is full enough, don't bother moving around the dictionary
 			return Storage::BLOCK_SIZE;
@@ -369,8 +383,9 @@ public:
 	// Buffers and map for current segment
 	std::vector<uint32_t> index_buffer;
 
-	size_t max_compressed_string_length = 0;
-	bitpacking_width_t current_width = 0;
+	size_t max_compressed_string_length;
+	bitpacking_width_t current_width;
+	idx_t last_fitting_size;
 
 	duckdb_fsst_encoder_t *fsst_encoder = nullptr;
 	unsigned char fsst_serialized_symbol_table[sizeof(duckdb_fsst_decoder_t)];
