@@ -1,6 +1,7 @@
 #include "duckdb/storage/single_file_block_manager.hpp"
 
 #include "duckdb/common/allocator.hpp"
+#include "duckdb/common/checksum.hpp"
 #include "duckdb/common/exception.hpp"
 #include "duckdb/common/serializer/buffered_deserializer.hpp"
 #include "duckdb/common/serializer/buffered_serializer.hpp"
@@ -30,11 +31,11 @@ void MainHeader::Serialize(Serializer &ser) {
 void MainHeader::CheckMagicBytes(FileHandle &handle) {
 	data_t magic_bytes[MAGIC_BYTE_SIZE];
 	if (handle.GetFileSize() < MainHeader::MAGIC_BYTE_SIZE + MainHeader::MAGIC_BYTE_OFFSET) {
-		throw IOException("The file is not a valid DuckDB database file!");
+		throw IOException("The file \"%s\" exists, but it is not a valid DuckDB database file!", handle.path);
 	}
 	handle.Read(magic_bytes, MainHeader::MAGIC_BYTE_SIZE, MainHeader::MAGIC_BYTE_OFFSET);
 	if (memcmp(magic_bytes, MainHeader::MAGIC_BYTES, MainHeader::MAGIC_BYTE_SIZE) != 0) {
-		throw IOException("The file is not a valid DuckDB database file!");
+		throw IOException("The file \"%s\" exists, but it is not a valid DuckDB database file!", handle.path);
 	}
 }
 
@@ -106,14 +107,14 @@ T DeserializeHeaderStructure(data_ptr_t ptr) {
 	return T::Deserialize(source);
 }
 
-SingleFileBlockManager::SingleFileBlockManager(AttachedDatabase &db, string path_p, bool read_only, bool create_new,
-                                               bool use_direct_io)
+SingleFileBlockManager::SingleFileBlockManager(AttachedDatabase &db, string path_p, bool read_only, bool use_direct_io)
     : BlockManager(BufferManager::GetBufferManager(db)), db(db), path(std::move(path_p)),
       header_buffer(Allocator::Get(db), FileBufferType::MANAGED_BUFFER,
                     Storage::FILE_HEADER_SIZE - Storage::BLOCK_HEADER_SIZE),
       iteration_count(0), read_only(read_only), use_direct_io(use_direct_io) {
-	uint8_t flags;
-	FileLockType lock;
+}
+
+void SingleFileBlockManager::GetFileFlags(uint8_t &flags, FileLockType &lock, bool create_new) {
 	if (read_only) {
 		D_ASSERT(!create_new);
 		flags = FileFlags::FILE_FLAGS_READ;
@@ -128,71 +129,108 @@ SingleFileBlockManager::SingleFileBlockManager(AttachedDatabase &db, string path
 	if (use_direct_io) {
 		flags |= FileFlags::FILE_FLAGS_DIRECT_IO;
 	}
+}
+
+void SingleFileBlockManager::CreateNewDatabase() {
+	uint8_t flags;
+	FileLockType lock;
+	GetFileFlags(flags, lock, true);
+
 	// open the RDBMS handle
 	auto &fs = FileSystem::Get(db);
 	handle = fs.OpenFile(path, flags, lock);
-	if (create_new) {
-		// if we create a new file, we fill the metadata of the file
-		// first fill in the new header
-		header_buffer.Clear();
 
-		MainHeader main_header;
-		main_header.version_number = VERSION_NUMBER;
-		memset(main_header.flags, 0, sizeof(uint64_t) * 4);
+	// if we create a new file, we fill the metadata of the file
+	// first fill in the new header
+	header_buffer.Clear();
 
-		SerializeHeaderStructure<MainHeader>(main_header, header_buffer.buffer);
-		// now write the header to the file
-		header_buffer.ChecksumAndWrite(*handle, 0);
-		header_buffer.Clear();
+	MainHeader main_header;
+	main_header.version_number = VERSION_NUMBER;
+	memset(main_header.flags, 0, sizeof(uint64_t) * 4);
 
-		// write the database headers
-		// initialize meta_block and free_list to INVALID_BLOCK because the database file does not contain any actual
-		// content yet
-		DatabaseHeader h1, h2;
-		// header 1
-		h1.iteration = 0;
-		h1.meta_block = INVALID_BLOCK;
-		h1.free_list = INVALID_BLOCK;
-		h1.block_count = 0;
-		SerializeHeaderStructure<DatabaseHeader>(h1, header_buffer.buffer);
-		header_buffer.ChecksumAndWrite(*handle, Storage::FILE_HEADER_SIZE);
-		// header 2
-		h2.iteration = 0;
-		h2.meta_block = INVALID_BLOCK;
-		h2.free_list = INVALID_BLOCK;
-		h2.block_count = 0;
-		SerializeHeaderStructure<DatabaseHeader>(h2, header_buffer.buffer);
-		header_buffer.ChecksumAndWrite(*handle, Storage::FILE_HEADER_SIZE * 2);
-		// ensure that writing to disk is completed before returning
-		handle->Sync();
-		// we start with h2 as active_header, this way our initial write will be in h1
-		iteration_count = 0;
-		active_header = 1;
-		max_block = 0;
+	SerializeHeaderStructure<MainHeader>(main_header, header_buffer.buffer);
+	// now write the header to the file
+	ChecksumAndWrite(header_buffer, 0);
+	header_buffer.Clear();
+
+	// write the database headers
+	// initialize meta_block and free_list to INVALID_BLOCK because the database file does not contain any actual
+	// content yet
+	DatabaseHeader h1, h2;
+	// header 1
+	h1.iteration = 0;
+	h1.meta_block = INVALID_BLOCK;
+	h1.free_list = INVALID_BLOCK;
+	h1.block_count = 0;
+	SerializeHeaderStructure<DatabaseHeader>(h1, header_buffer.buffer);
+	ChecksumAndWrite(header_buffer, Storage::FILE_HEADER_SIZE);
+	// header 2
+	h2.iteration = 0;
+	h2.meta_block = INVALID_BLOCK;
+	h2.free_list = INVALID_BLOCK;
+	h2.block_count = 0;
+	SerializeHeaderStructure<DatabaseHeader>(h2, header_buffer.buffer);
+	ChecksumAndWrite(header_buffer, Storage::FILE_HEADER_SIZE * 2);
+	// ensure that writing to disk is completed before returning
+	handle->Sync();
+	// we start with h2 as active_header, this way our initial write will be in h1
+	iteration_count = 0;
+	active_header = 1;
+	max_block = 0;
+}
+
+void SingleFileBlockManager::LoadExistingDatabase() {
+	uint8_t flags;
+	FileLockType lock;
+	GetFileFlags(flags, lock, false);
+
+	// open the RDBMS handle
+	auto &fs = FileSystem::Get(db);
+	handle = fs.OpenFile(path, flags, lock);
+
+	MainHeader::CheckMagicBytes(*handle);
+	// otherwise, we check the metadata of the file
+	ReadAndChecksum(header_buffer, 0);
+	DeserializeHeaderStructure<MainHeader>(header_buffer.buffer);
+
+	// read the database headers from disk
+	DatabaseHeader h1, h2;
+	ReadAndChecksum(header_buffer, Storage::FILE_HEADER_SIZE);
+	h1 = DeserializeHeaderStructure<DatabaseHeader>(header_buffer.buffer);
+	ReadAndChecksum(header_buffer, Storage::FILE_HEADER_SIZE * 2);
+	h2 = DeserializeHeaderStructure<DatabaseHeader>(header_buffer.buffer);
+	// check the header with the highest iteration count
+	if (h1.iteration > h2.iteration) {
+		// h1 is active header
+		active_header = 0;
+		Initialize(h1);
 	} else {
-		MainHeader::CheckMagicBytes(*handle);
-		// otherwise, we check the metadata of the file
-		header_buffer.ReadAndChecksum(*handle, 0);
-		DeserializeHeaderStructure<MainHeader>(header_buffer.buffer);
-
-		// read the database headers from disk
-		DatabaseHeader h1, h2;
-		header_buffer.ReadAndChecksum(*handle, Storage::FILE_HEADER_SIZE);
-		h1 = DeserializeHeaderStructure<DatabaseHeader>(header_buffer.buffer);
-		header_buffer.ReadAndChecksum(*handle, Storage::FILE_HEADER_SIZE * 2);
-		h2 = DeserializeHeaderStructure<DatabaseHeader>(header_buffer.buffer);
-		// check the header with the highest iteration count
-		if (h1.iteration > h2.iteration) {
-			// h1 is active header
-			active_header = 0;
-			Initialize(h1);
-		} else {
-			// h2 is active header
-			active_header = 1;
-			Initialize(h2);
-		}
-		LoadFreeList();
+		// h2 is active header
+		active_header = 1;
+		Initialize(h2);
 	}
+	LoadFreeList();
+}
+
+void SingleFileBlockManager::ReadAndChecksum(FileBuffer &block, uint64_t location) const {
+	// read the buffer from disk
+	block.Read(*handle, location);
+	// compute the checksum
+	auto stored_checksum = Load<uint64_t>(block.InternalBuffer());
+	uint64_t computed_checksum = Checksum(block.buffer, block.size);
+	// verify the checksum
+	if (stored_checksum != computed_checksum) {
+		throw IOException("Corrupt database file: computed checksum %llu does not match stored checksum %llu in block",
+		                  computed_checksum, stored_checksum);
+	}
+}
+
+void SingleFileBlockManager::ChecksumAndWrite(FileBuffer &block, uint64_t location) const {
+	// compute the checksum and write it to the start of the buffer (if not temp buffer)
+	uint64_t checksum = Checksum(block.buffer, block.size);
+	Store<uint64_t>(checksum, block.InternalBuffer());
+	// now write the buffer
+	block.Write(*handle, location);
 }
 
 void SingleFileBlockManager::Initialize(DatabaseHeader &header) {
@@ -317,12 +355,12 @@ unique_ptr<Block> SingleFileBlockManager::CreateBlock(block_id_t block_id, FileB
 void SingleFileBlockManager::Read(Block &block) {
 	D_ASSERT(block.id >= 0);
 	D_ASSERT(std::find(free_list.begin(), free_list.end(), block.id) == free_list.end());
-	block.ReadAndChecksum(*handle, BLOCK_START + block.id * Storage::BLOCK_ALLOC_SIZE);
+	ReadAndChecksum(block, BLOCK_START + block.id * Storage::BLOCK_ALLOC_SIZE);
 }
 
 void SingleFileBlockManager::Write(FileBuffer &buffer, block_id_t block_id) {
 	D_ASSERT(block_id >= 0);
-	buffer.ChecksumAndWrite(*handle, BLOCK_START + block_id * Storage::BLOCK_ALLOC_SIZE);
+	ChecksumAndWrite(buffer, BLOCK_START + block_id * Storage::BLOCK_ALLOC_SIZE);
 }
 
 vector<block_id_t> SingleFileBlockManager::GetFreeListBlocks() {
@@ -431,8 +469,7 @@ void SingleFileBlockManager::WriteHeader(DatabaseHeader header) {
 	Store<DatabaseHeader>(header, header_buffer.buffer);
 	// now write the header to the file, active_header determines whether we write to h1 or h2
 	// note that if active_header is h1 we write to h2, and vice versa
-	header_buffer.ChecksumAndWrite(*handle,
-	                               active_header == 1 ? Storage::FILE_HEADER_SIZE : Storage::FILE_HEADER_SIZE * 2);
+	ChecksumAndWrite(header_buffer, active_header == 1 ? Storage::FILE_HEADER_SIZE : Storage::FILE_HEADER_SIZE * 2);
 	// switch active header to the other header
 	active_header = 1 - active_header;
 	//! Ensure the header write ends up on disk
