@@ -9,7 +9,8 @@ struct StorageVersionInfo {
 	idx_t storage_version;
 };
 
-static StorageVersionInfo storage_version_info[] = {{"v0.6.0 or v0.6.1", 39},
+static StorageVersionInfo storage_version_info[] = {{"v0.7.0", 43},
+                                                    {"v0.6.0 or v0.6.1", 39},
                                                     {"v0.5.0 or v0.5.1", 38},
                                                     {"v0.3.3, v0.3.4 or v0.4.0", 33},
                                                     {"v0.3.2", 31},
