@@ -1,5 +1,11 @@
 #include "src/catalog/catalog_entry/copy_function_catalog_entry.cpp"
 
+#include "src/catalog/catalog_entry/duck_index_entry.cpp"
+
+#include "src/catalog/catalog_entry/duck_schema_entry.cpp"
+
+#include "src/catalog/catalog_entry/duck_table_entry.cpp"
+
 #include "src/catalog/catalog_entry/type_catalog_entry.cpp"
 
 #include "src/catalog/catalog_entry/index_catalog_entry.cpp"
