@@ -1,5 +1,7 @@
 #include "src/execution/index/art/art_key.cpp"
 
+#include "src/execution/index/art/iterator.cpp"
+
 #include "src/execution/index/art/leaf.cpp"
 
 #include "src/execution/index/art/node.cpp"
@@ -12,5 +14,9 @@
 
 #include "src/execution/index/art/node256.cpp"
 
+#include "src/execution/index/art/swizzleable_pointer.cpp"
+
+#include "src/execution/index/art/prefix.cpp"
+
 #include "src/execution/index/art/art.cpp"
 
