@@ -1,7 +1,5 @@
 #include "src/planner/binder/tableref/bind_basetableref.cpp"
 
-#include "src/planner/binder/tableref/bind_crossproductref.cpp"
-
 #include "src/planner/binder/tableref/bind_emptytableref.cpp"
 
 #include "src/planner/binder/tableref/bind_expressionlistref.cpp"
@@ -16,8 +14,6 @@
 
 #include "src/planner/binder/tableref/plan_basetableref.cpp"
 
-#include "src/planner/binder/tableref/plan_crossproductref.cpp"
-
 #include "src/planner/binder/tableref/plan_dummytableref.cpp"
 
 #include "src/planner/binder/tableref/plan_expressionlistref.cpp"
